@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*                                                                            */
 /*     Copyright (C) 2010-2018 Pierre Biava (grisbi@pierre.biava.name)        */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -724,8 +724,10 @@ static void bet_finance_ui_switch_amortization_initial_date (GtkWidget *widget,
     GtkWidget *tmp_button;
     gint account_number;
     gboolean amortization_initial_date;
-    devel_debug (NULL);
+	GrisbiAppConf *a_conf;
 
+	devel_debug (NULL);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
     amortization_initial_date = GPOINTER_TO_INT (g_object_get_data ( G_OBJECT (tree_view),
 																	"amortization_initial_date"));
     amortization_initial_date = !amortization_initial_date;
@@ -739,7 +741,7 @@ static void bet_finance_ui_switch_amortization_initial_date (GtkWidget *widget,
 	else
 		tmp_button = g_object_get_data (G_OBJECT (tree_view), "amortization_initial_date_button");
 
-    if (conf.display_toolbar != GSB_BUTTON_ICON)
+    if (a_conf->display_toolbar != GSB_BUTTON_ICON)
     {
 		if (amortization_initial_date)
 			gtk_tool_button_set_label (GTK_TOOL_BUTTON (tmp_button), _("At today"));
@@ -952,8 +954,6 @@ static GtkWidget *bet_finance_ui_create_amortization_page (void)
     GtkWidget *label;
     GtkWidget *tree_view;
 
-    devel_debug (NULL);
-
     page = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
 
     /* frame pour la barre d'outils */
@@ -1040,7 +1040,6 @@ static GtkWidget *bet_finance_ui_create_data_tree_view (GtkWidget *container)
     gchar *title;
 
     tree_view = gtk_tree_view_new ();
-	gtk_widget_set_name (tree_view, "tree_view");
 
     /* Create the tree store */
     tree_model = gtk_tree_store_new (BET_FINANCE_NBRE_COLUMNS,
@@ -1248,11 +1247,10 @@ static gboolean bet_finance_ui_duration_button_changed (GtkWidget *combobox,
 static GtkWidget *bet_finance_ui_create_duration_widget (GtkWidget *parent)
 {
     GtkWidget *combobox;
-    gchar *text_duration [] = {
-    _("Between 3 and 18 months"),
-    _("Between 1 and 15 years"),
-    _("Between 15 and 30 years"),
-    NULL};
+    const gchar *text_duration [] = {N_("Between 3 and 18 months"),
+									 N_("Between 1 and 15 years"),
+    								 N_("Between 15 and 30 years"),
+    								 NULL};
 
     combobox = gsb_combo_box_new_with_index (text_duration,
 											 G_CALLBACK (bet_finance_ui_duration_button_changed),
@@ -1324,48 +1322,63 @@ static void bet_finance_ui_type_taux_changed (GtkWidget *togglebutton,
  *
  * \return
  **/
-static GtkWidget *bet_finance_ui_create_saisie_widget (GtkWidget *parent)
+static void bet_finance_ui_create_saisie_widget (GtkWidget *page,
+												 GtkWidget *grid)
 {
-    GtkWidget *vbox;
     GtkWidget *hbox;
     GtkWidget *label;
     GtkWidget *spin_button = NULL;
     GtkWidget *button_1, *button_2;
     gchar *tmp_str;
 
-    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
+    /* taux */
+    label = gtk_label_new (_("Annual interest: "));
+    utils_labels_set_alignment (GTK_LABEL (label), GSB_LEFT, GSB_CENTER);
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1 ,1);
+
+    spin_button = gtk_spin_button_new_with_range (0.0, 100,
+                        bet_data_finance_get_bet_taux_step (BET_TAUX_DIGITS));
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_button), etat.bet_taux_annuel);
+    g_object_set_data (G_OBJECT (page), "taux", spin_button);
+	gtk_grid_attach (GTK_GRID (grid), spin_button, 1, 1, 1 ,1);
+    g_signal_connect (spin_button,
+					  "value-changed",
+					  G_CALLBACK (bet_finance_ui_spin_button_taux_changed),
+					  page);
+
+    label = gtk_label_new (_("%"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_widget_set_halign (label, GTK_ALIGN_START);
+	gtk_grid_attach (GTK_GRID (grid), label, 2, 1, 1 ,1);
 
     /* Frais */
-    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
-	gtk_widget_set_halign (hbox, GTK_ALIGN_CENTER);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-
     label = gtk_label_new (_("Fees: "));
     utils_labels_set_alignment (GTK_LABEL (label), GSB_LEFT, GSB_CENTER);
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 5);
+    gtk_grid_attach (GTK_GRID (grid), label, 3, 1, 1 ,1);
 
     spin_button = gtk_spin_button_new_with_range (0.0,
 												  100,
 												  bet_data_finance_get_bet_taux_step (BET_TAUX_DIGITS));
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_button), etat.bet_frais);
-    g_object_set_data (G_OBJECT (parent), "frais", spin_button);
-    gtk_box_pack_start (GTK_BOX (hbox), spin_button, FALSE, FALSE, 0);
+    g_object_set_data (G_OBJECT (page), "frais", spin_button);
+	gtk_grid_attach (GTK_GRID (grid), spin_button, 4, 1, 1 ,1);
     g_signal_connect (spin_button,
 					  "value-changed",
 					  G_CALLBACK (bet_finance_ui_spin_button_fees_changed),
-					  parent);
+					  page);
 
-    tmp_str = g_strconcat (_("%"), _(" of borrowed capital"), NULL);
+    tmp_str = g_strconcat (_("%"), _(" of capital"), NULL);
     label = gtk_label_new (tmp_str);
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, MARGIN_BOX);
+    gtk_grid_attach (GTK_GRID (grid), label, 5, 1, 1 ,1);
     g_free (tmp_str);
 
     /* Type de taux */
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
 	gtk_widget_set_halign (hbox, GTK_ALIGN_CENTER);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    gtk_grid_attach (GTK_GRID (grid), hbox, 0, 2, 6 ,1);
 
     label = gtk_label_new (_("Rate Type: "));
     utils_labels_set_alignment (GTK_LABEL (label), GSB_LEFT, GSB_CENTER);
@@ -1375,7 +1388,7 @@ static GtkWidget *bet_finance_ui_create_saisie_widget (GtkWidget *parent)
 
     button_2 = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (button_1),
 															_("Proportional rate"));
-    g_object_set_data (G_OBJECT (parent), "type_taux", button_2);
+    g_object_set_data (G_OBJECT (page), "type_taux", button_2);
 
     if (etat.bet_type_taux)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_2), TRUE);
@@ -1387,15 +1400,11 @@ static GtkWidget *bet_finance_ui_create_saisie_widget (GtkWidget *parent)
     g_signal_connect (button_1,
 					  "button-release-event",
 					  G_CALLBACK (bet_finance_ui_type_taux_changed),
-					  parent);
+					  page);
     g_signal_connect (button_2,
 					  "button-release-event",
 					  G_CALLBACK (bet_finance_ui_type_taux_changed),
-					  parent);
-
-    gtk_widget_show_all (vbox);
-
-    return vbox;
+					  page);
 }
 
 /**
@@ -1425,15 +1434,12 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
     GtkWidget *page;
     GtkWidget *frame;
     GtkWidget *widget;
-    GtkWidget *hbox;
+    GtkWidget *grid;
     GtkWidget *label_title;
     GtkWidget *label;
-    GtkWidget *spin_button = NULL;
     GtkWidget *tree_view;
     gchar *str_capital;
 
-    devel_debug (NULL);
-
     page = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
 
     /* frame pour la barre d'outils */
@@ -1446,15 +1452,17 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
     gtk_box_pack_start (GTK_BOX (page), label_title, FALSE, FALSE, MARGIN_BOX);
 
     /* Choix des données sources */
-    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
-	gtk_widget_set_halign (hbox, GTK_ALIGN_CENTER);
-    gtk_box_pack_start (GTK_BOX (page), hbox, FALSE, FALSE, MARGIN_BOX);
+	grid = gtk_grid_new ();
+	gtk_grid_set_column_spacing (GTK_GRID (grid), MARGIN_BOX);
+	gtk_grid_set_row_spacing (GTK_GRID (grid), MARGIN_BOX);
+	gtk_widget_set_margin_start (grid, MARGIN_BOX);
+    gtk_box_pack_start (GTK_BOX (page), grid, FALSE, FALSE, MARGIN_BOX);
 
     /* capital */
     label = gtk_label_new (_("Loan capital: "));
     utils_labels_set_alignment (GTK_LABEL (label), GSB_LEFT, GSB_CENTER);
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, MARGIN_BOX);
+	gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1 ,1);
 
     str_capital = utils_real_get_string_with_currency (gsb_real_double_to_real (etat.bet_capital),
 													   etat.bet_currency,
@@ -1463,7 +1471,7 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
     widget = gtk_entry_new ();
     gtk_entry_set_text (GTK_ENTRY (widget), str_capital);
     g_object_set_data (G_OBJECT (page), "capital", widget);
-    gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, MARGIN_BOX);
+	gtk_grid_attach (GTK_GRID (grid), widget, 1, 0, 1 ,1);
     g_signal_connect (G_OBJECT (widget),
 					  "changed",
 					  G_CALLBACK (bet_finance_ui_capital_entry_changed),
@@ -1479,45 +1487,24 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
     widget = gsb_currency_make_combobox (FALSE);
     gsb_currency_set_combobox_history (widget, etat.bet_currency);
     g_object_set_data (G_OBJECT (page), "devise", widget);
-    gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (grid), widget, 2, 0, 1 ,1);
     g_signal_connect (G_OBJECT ( widget),
 					  "changed",
 					  G_CALLBACK (bet_finance_ui_currency_changed),
 					  page);
 
-    /* taux */
-    label = gtk_label_new (_("Annual interest: "));
-    utils_labels_set_alignment (GTK_LABEL (label), GSB_LEFT, GSB_CENTER);
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, MARGIN_BOX);
-
-    spin_button = gtk_spin_button_new_with_range (0.0, 100,
-                        bet_data_finance_get_bet_taux_step (BET_TAUX_DIGITS));
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_button), etat.bet_taux_annuel);
-    g_object_set_data (G_OBJECT (page), "taux", spin_button);
-    gtk_box_pack_start (GTK_BOX (hbox), spin_button, FALSE, FALSE, 0);
-    g_signal_connect (spin_button,
-					  "value-changed",
-					  G_CALLBACK (bet_finance_ui_spin_button_taux_changed),
-					  page);
-
-    label = gtk_label_new (_("%"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, MARGIN_BOX);
-
     /* Duration */
     label = gtk_label_new (_("Duration: "));
     utils_labels_set_alignment (GTK_LABEL (label), GSB_LEFT, GSB_CENTER);
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, MARGIN_BOX);
+	gtk_grid_attach (GTK_GRID (grid), label, 3, 0, 1 ,1);
 
     widget = bet_finance_ui_create_duration_widget (page);
     g_object_set_data (G_OBJECT (page), "duree", widget);
-    gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+	gtk_grid_attach (GTK_GRID (grid), widget, 4, 0, 1 ,1);
 
     /* création du widget saisie détaillée */
-    widget = bet_finance_ui_create_saisie_widget (page);
-    gtk_box_pack_start (GTK_BOX (page), widget, FALSE, FALSE, MARGIN_BOX);
+	bet_finance_ui_create_saisie_widget (page, grid);
 
     /* création de la liste des données */
     tree_view = bet_finance_ui_create_data_tree_view (page);
@@ -1526,7 +1513,7 @@ static GtkWidget *bet_finance_ui_create_simulator_page (void)
     g_object_set_data (G_OBJECT (tree_view), "label_title", label_title);
 
     /* set the color of selected row */
-	gtk_widget_set_name (tree_view, "tree_view");
+	gtk_widget_set_name (tree_view, "colorized_tree_view");
 
     /* on y ajoute la barre d'outils */
     simulator_toolbar = bet_finance_ui_create_simulator_toolbar (page, tree_view, TRUE, FALSE);
@@ -1677,7 +1664,6 @@ GtkWidget *bet_finance_ui_create_account_amortization_page (void)
     GtkWidget *account_page;
 
     devel_debug (NULL);
-
     account_page = grisbi_win_get_account_page ();
 
     /* frame pour la barre d'outils */
@@ -1693,7 +1679,7 @@ GtkWidget *bet_finance_ui_create_account_amortization_page (void)
     g_object_set_data (G_OBJECT (tree_view), "label_title", label_title);
 
     /* set the color of selected row */
-	gtk_widget_set_name (tree_view, "tree_view");
+	gtk_widget_set_name (tree_view, "colorized_tree_view");
 
     /* on y ajoute la barre d'outils */
 	frame = g_object_get_data (G_OBJECT (account_page), "frame");
@@ -1720,7 +1706,6 @@ GtkWidget *bet_finance_ui_create_amortization_heading (GtkWidget *parent)
     GtkWidget *label_title;
     GtkWidget *label;
 
-    devel_debug (NULL);
     heading = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
 
     /* frame pour la barre d'outils */
@@ -1800,9 +1785,7 @@ GtkWidget *bet_finance_ui_create_amortization_tree_view (GtkWidget *container,
     GtkTreeViewColumn *column;
     gchar *title;
 
-    devel_debug (NULL);
     tree_view = gtk_tree_view_new ();
-	gtk_widget_set_name (tree_view, "tree_view");
     g_object_set_data (G_OBJECT (tree_view), "amortization_initial_date", GINT_TO_POINTER (FALSE));
 
     /* Create the tree store */
@@ -1830,7 +1813,7 @@ GtkWidget *bet_finance_ui_create_amortization_tree_view (GtkWidget *container,
 													   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
 													   NULL);
 	g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_NUMBER_COLUMN));
-	g_object_set_data (G_OBJECT (column), "name", "NumEch");
+	g_object_set_data (G_OBJECT (column), "name", (gchar*)"NumEch");
     g_free (title);
 
     gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
@@ -1851,7 +1834,7 @@ GtkWidget *bet_finance_ui_create_amortization_tree_view (GtkWidget *container,
 														   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
 														   NULL);
 		g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_DATE_COLUMN));
-		g_object_set_data (G_OBJECT (column), "name", "Date");
+		g_object_set_data (G_OBJECT (column), "name", (gchar*)"Date");
 		g_free (title);
 		gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
 		gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
@@ -1859,23 +1842,47 @@ GtkWidget *bet_finance_ui_create_amortization_tree_view (GtkWidget *container,
 		gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
 	}
 
-    /* Capital restant dû */
-    title = g_strdup (_("Capital remaining"));
-    cell = gtk_cell_renderer_text_new ();
-    g_object_set (G_OBJECT (cell), "xalign", GSB_CENTER, NULL);
+	/* Inversion des colonnes Capital_du et echéance fix Gtk-WARNING **: 13:32:11.757: Negative content height -1 */
+	if (origin == SPP_ORIGIN_INVERSE_FINANCE)
+	{
+		/* Monthly paid */
+		title = g_strdup (_("Monthly paid"));
+		cell = gtk_cell_renderer_text_new ();
+		g_object_set (G_OBJECT (cell), "xalign", GSB_CENTER, NULL);
 
-    column = gtk_tree_view_column_new_with_attributes (title,
+		column = gtk_tree_view_column_new_with_attributes (title,
 														   cell,
-														   "text", BET_AMORTIZATION_CAPITAL_DU_COLUMN,
+														   "text", BET_AMORTIZATION_ECHEANCE_COLUMN,
 														   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
 														   NULL);
-    g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_CAPITAL_DU_COLUMN));
-	g_object_set_data (G_OBJECT (column), "name", "CapitalDu");
-    g_free (title);
-    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
-    gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
-    gtk_tree_view_column_set_resizable (column, TRUE);
-    gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
+		g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_ECHEANCE_COLUMN));
+		g_object_set_data (G_OBJECT (column), "name", (gchar*)"Echeance");
+		g_free (title);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
+		gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
+		gtk_tree_view_column_set_resizable (column, TRUE);
+		gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
+	}
+	else
+	{
+		/* Capital restant dû */
+		title = g_strdup (_("Capital remaining"));
+		cell = gtk_cell_renderer_text_new ();
+		g_object_set (G_OBJECT (cell), "xalign", GSB_CENTER, NULL);
+
+		column = gtk_tree_view_column_new_with_attributes (title,
+															   cell,
+															   "text", BET_AMORTIZATION_CAPITAL_DU_COLUMN,
+															   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
+															   NULL);
+		g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_CAPITAL_DU_COLUMN));
+		g_object_set_data (G_OBJECT (column), "name", (gchar*)"CapitalDu");
+		g_free (title);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
+		gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
+		gtk_tree_view_column_set_resizable (column, TRUE);
+		gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
+	}
 
     /* Interests */
     title = g_strdup (_("Capital repaid"));
@@ -1888,7 +1895,7 @@ GtkWidget *bet_finance_ui_create_amortization_tree_view (GtkWidget *container,
 													   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
 													   NULL);
     g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_PRINCIPAL_COLUMN));
-	g_object_set_data (G_OBJECT (column), "name", "Principal");
+	g_object_set_data (G_OBJECT (column), "name", (gchar*)"Principal");
     g_free (title);
     gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
     gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
@@ -1906,7 +1913,7 @@ GtkWidget *bet_finance_ui_create_amortization_tree_view (GtkWidget *container,
 													   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
 													   NULL);
     g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_INTERETS_COLUMN));
-	g_object_set_data (G_OBJECT (column), "name", "Interests");
+	g_object_set_data (G_OBJECT (column), "name", (gchar*)"Interests");
     g_free (title);
     gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
     gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
@@ -1925,29 +1932,52 @@ GtkWidget *bet_finance_ui_create_amortization_tree_view (GtkWidget *container,
 													   NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
     g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_FRAIS_COLUMN));
-	g_object_set_data (G_OBJECT (column), "name", "Fees");
+	g_object_set_data (G_OBJECT (column), "name", (gchar*)"Fees");
     g_free (title);
 	gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
     gtk_tree_view_column_set_resizable (column, TRUE);
     gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
 
-	/* Monthly paid */
-    title = g_strdup (_("Monthly paid"));
-    cell = gtk_cell_renderer_text_new ();
-    g_object_set (G_OBJECT (cell), "xalign", GSB_CENTER, NULL);
+	if (origin == SPP_ORIGIN_INVERSE_FINANCE)
+	{
+		/* Capital restant dû */
+		title = g_strdup (_("Capital remaining"));
+		cell = gtk_cell_renderer_text_new ();
+		g_object_set (G_OBJECT (cell), "xalign", GSB_CENTER, NULL);
 
-    column = gtk_tree_view_column_new_with_attributes (title,
-													   cell,
-													   "text", BET_AMORTIZATION_ECHEANCE_COLUMN,
-													   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
-													   NULL);
-    g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_ECHEANCE_COLUMN));
-	g_object_set_data (G_OBJECT (column), "name", "Echeance");
-    g_free (title);
-    gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
-    gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
-    gtk_tree_view_column_set_resizable (column, TRUE);
-    gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
+		column = gtk_tree_view_column_new_with_attributes (title,
+															   cell,
+															   "text", BET_AMORTIZATION_CAPITAL_DU_COLUMN,
+															   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
+															   NULL);
+		g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_CAPITAL_DU_COLUMN));
+		g_object_set_data (G_OBJECT (column), "name", (gchar*)"CapitalDu");
+		g_free (title);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
+		gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
+		gtk_tree_view_column_set_resizable (column, TRUE);
+		gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
+	}
+	else
+	{
+		/* Monthly paid */
+		title = g_strdup (_("Monthly paid"));
+		cell = gtk_cell_renderer_text_new ();
+		g_object_set (G_OBJECT (cell), "xalign", GSB_CENTER, NULL);
+
+		column = gtk_tree_view_column_new_with_attributes (title,
+														   cell,
+														   "text", BET_AMORTIZATION_ECHEANCE_COLUMN,
+														   "cell-background-rgba", BET_AMORTIZATION_BACKGROUND_COLOR,
+														   NULL);
+		g_object_set_data (G_OBJECT (column), "num_col_model", GINT_TO_POINTER (BET_AMORTIZATION_ECHEANCE_COLUMN));
+		g_object_set_data (G_OBJECT (column), "name", (gchar*)"Echeance");
+		g_free (title);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), GTK_TREE_VIEW_COLUMN (column));
+		gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
+		gtk_tree_view_column_set_resizable (column, TRUE);
+		gtk_tree_view_column_set_alignment (column, COLUMN_CENTER);
+	}
 
     g_signal_connect (G_OBJECT (tree_view),
 					  "button-press-event",
@@ -2288,6 +2318,7 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
 	gint index_last_installment_paid = 0;
     gboolean amortization_initial_date;
 	gboolean first_echeance = FALSE;
+	gint origin;
     AmortissementStruct *s_amortissement;
 
     devel_debug (NULL);
@@ -2297,7 +2328,9 @@ void bet_finance_update_amortization_tab_with_data (gint account_number,
 
     /* récupère le tableau d'amortissement */
     tree_view = g_object_get_data (G_OBJECT (parent), "bet_finance_tree_view");
-	bet_finance_ui_invers_cols_cap_ech_amortization (tree_view, s_loan->invers_cols_cap_ech);
+	origin = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (tree_view), "origin"));
+	if (origin != SPP_ORIGIN_CONFIG)
+		bet_finance_ui_invers_cols_cap_ech_amortization (tree_view, s_loan->invers_cols_cap_ech);
 	amortization_initial_date = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (tree_view),
 																	"amortization_initial_date"));
 
