@@ -2071,6 +2071,18 @@ GtkTreeModel *bet_historical_get_bet_fyear_model_filter (void)
 	return bet_fyear_model_filter;
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+GtkWidget *bet_historical_get_toolbar (void)
+{
+	return bet_historical_toolbar;
+}
+
 /**
  *
  *
