@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2004-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2009-2011 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -119,9 +119,7 @@ GtkWidget *categories_create_list ( void )
     GtkCellRenderer *cell;
     GtkTreeDragDestIface * dst_iface;
     GtkTreeDragSourceIface * src_iface;
-    static GtkTargetEntry row_targets[] = {
-	{ "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }
-    };
+    static GtkTargetEntry row_targets[] = {{(gchar*)"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }};
     MetatreeInterface *category_interface;
 
 	window = GTK_WIDGET (grisbi_app_get_active_window (NULL));
@@ -139,7 +137,7 @@ GtkWidget *categories_create_list ( void )
     arbre_categ = gtk_tree_view_new();
 
     /* set the color of selected row */
-	gtk_widget_set_name (arbre_categ, "tree_view");
+	gtk_widget_set_name (arbre_categ, "colorized_tree_view");
 
     /* Create model */
     categ_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES );
@@ -527,7 +525,7 @@ void categories_importer_list ( void )
 		case 2 :
 			/* we want to replace the list */
 			if ( !last_transaction_number )
-				gsb_data_category_init_variables ();
+				gsb_data_category_init_variables (TRUE);
 			gsb_file_others_load_category ( category_name );
 
 		default :
@@ -1022,6 +1020,7 @@ gboolean category_list_button_press ( GtkWidget *tree_view,
         GtkTreeIter iter;
         GtkTreePath *path = NULL;
         enum MetaTreeRowType type_division;
+		GrisbiAppConf *a_conf;
 
         type_division = metatree_get_row_type_from_tree_view ( tree_view );
         if ( type_division == META_TREE_TRANSACTION )
@@ -1033,7 +1032,8 @@ gboolean category_list_button_press ( GtkWidget *tree_view,
 		else
 			return FALSE;
 
-        if ( conf.metatree_action_2button_press == 0 || type_division == META_TREE_DIV )
+		a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+        if ( a_conf->metatree_action_2button_press == 0 || type_division == META_TREE_DIV )
         {
             if ( gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), path ) )
                 gtk_tree_view_collapse_row ( GTK_TREE_VIEW ( tree_view ), path );
@@ -1043,7 +1043,7 @@ gboolean category_list_button_press ( GtkWidget *tree_view,
             gtk_tree_path_free ( path );
             return FALSE;
         }
-        else if ( conf.metatree_action_2button_press == 1 )
+        else if ( a_conf->metatree_action_2button_press == 1 )
         {
             edit_category ( GTK_TREE_VIEW ( tree_view ) );
 
