@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2005-2006 Benjamin Drieu (bdrieu@april.org)           */
 /*          2008-2017 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -54,7 +54,7 @@ static gchar *sanitize_field (gchar *begin,
  *
  */
 GSList *csv_parse_line (gchar **contents,
-						gchar *separator)
+						const gchar *separator)
 {
     gchar *tmp;
     gchar *begin;
@@ -62,6 +62,9 @@ GSList *csv_parse_line (gchar **contents,
     gsize len;
     GSList *list = NULL;
 
+	if (!separator || strlen (separator) == 0)
+		return NULL;
+
     len = strlen (separator);
     tmp = (*contents);
     begin = tmp;
@@ -142,12 +145,7 @@ gchar *sanitize_field (gchar *begin,
 
     if (end <= begin)
 	{
-        return "";
-	}
-
-	if ((end-begin) == 1)
-	{
-		return "";
+        return (gchar*)"";
 	}
 
     iter = field = g_malloc0 (end - begin + 1);
