@@ -4,7 +4,7 @@
 #include "gsb_real.h"
 /* END_INCLUDE_H */
 
-/* constantes definissant le niveau de debug */
+/* constantes definissant le niveau de debug 1 = alertes les plus graves */
 #define DEBUG_NO_DEBUG				0		/* pas de de débug */
 #define	DEBUG_LEVEL_ALERT			1		/* grave probleme */
 #define DEBUG_LEVEL_IMPORTANT		2		/* probleme moins grave */
@@ -15,6 +15,7 @@
 
 #define devel_debug_int(x) debug_message_int("Debug",__FILE__,__LINE__,__PRETTY_FUNCTION__,x,DEBUG_LEVEL_DEBUG,FALSE)
 #define devel_debug_real(x) debug_message_real("Debug",__FILE__,__LINE__,__PRETTY_FUNCTION__,x,DEBUG_LEVEL_DEBUG,FALSE)
+#define devel_debug_ptr(x) debug_message_ptr("Debug",__FILE__,__LINE__,__PRETTY_FUNCTION__,x,DEBUG_LEVEL_DEBUG,FALSE)
 #define devel_debug(x) debug_message_string("Debug",__FILE__,__LINE__,__PRETTY_FUNCTION__,x,DEBUG_LEVEL_DEBUG,FALSE)
 #define notice_debug(x) debug_message_string("Info",__FILE__,__LINE__,__PRETTY_FUNCTION__,x,DEBUG_LEVEL_INFO,FALSE)
 #define warning_debug(x) debug_message_string("Warning",__FILE__,__LINE__,__PRETTY_FUNCTION__,x,DEBUG_LEVEL_NOTICE,FALSE)
@@ -24,6 +25,7 @@
 #define devel_print_str(x) debug_print_log_string("Debug",__FILE__,__LINE__,__PRETTY_FUNCTION__,x)
 
 /* START_DECLARATION */
+gboolean	debug_get_debug_mode			(void);
 void 		debug_message_int 				(const gchar *prefixe,
 											 const gchar *file,
 											 gint line,
@@ -38,6 +40,13 @@ void 		debug_message_real 				(const gchar *prefixe,
 											 GsbReal message,
 											 gint level,
 											 gboolean force_debug_display);
+void 		debug_message_ptr 				(const gchar *prefixe,
+											 const gchar *file,
+											 gint line,
+											 const char *function,
+											 void * message,
+											 gint level,
+											 gboolean force_debug_display);
 void 		debug_message_string 			(const gchar *prefixe,
 											 const gchar *file,
 											 gint line,
@@ -56,5 +65,6 @@ void 		debug_initialize_debugging 		(gint level);
 void 		debug_set_cmd_line_debug_level 	(gint debug_level);
 void 		debug_set_cmd_line_mode 		(gint level);
 void 		debug_traitement_sigsegv 		(gint signal_nb) __attribute__ ((noreturn));
+void		debug_start_log_file(void);
 /* END_DECLARATION */
 #endif
