@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)         2005 Benjamin Drieu (bdrieu@april.org)           */
 /*          2009 Pierre Biava (grisbi@pierre.biava.name)                      */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -92,7 +92,7 @@ void csv_attach_label ( gchar * text, gdouble properties, gint x, gint x2, gint
     gint pad;
 
     if ( !text )
-	text = "";
+	text = (gchar*)"";
 
     if ( y >= csv_lastline )
     {
