@@ -2,7 +2,7 @@
 /*      etats_html.c */
 
 /*     Copyright (C)	2004 Benjamin Drieu (bdrieu@april.org)		      */
-/* 			http://www.grisbi.org				      */
+/* 			https://www.grisbi.org				      */
 
 /*     This program is free software; you can redistribute it and/or modify */
 /*     it under the terms of the GNU General Public License as published by */
@@ -104,7 +104,7 @@ void html_attach_label ( gchar * text, gdouble properties, int x, int x2, int y,
 
 
     if ( !text )
-	text = "";
+	text = (gchar*)"";
 
     if ( y >= html_lastline )
     {
