@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cedric Auger (cedric@grisbi.org)            */
 /*          2002-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2008-2018 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -52,6 +52,7 @@
 #include "traitement_variables.h"
 #include "utils.h"
 #include "utils_files.h"
+#include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -65,6 +66,9 @@ static GtkWidget *	bouton_exporter_etat = NULL;
 static GtkWidget *	bouton_dupliquer_etat = NULL;
 static GtkWidget *	notebook_etats = NULL;
 static GtkWidget *	reports_toolbar = NULL;
+
+/* sert à nommer la recherche */
+static gint			search_number = 1;
 /*END_STATIC*/
 
 /*START_EXTERN*/
@@ -176,9 +180,9 @@ static void etats_onglet_change_choix_nouvel_etat (GtkWidget *combobox,
 		case 5:
 			/* Monthly outgoings by payee */
 			if (w_etat->metatree_assoc_mode)
-				description = "Cet état affiche les dépenses du mois classées par tiers. "
-				"Vous aurez juste à choisir le ou les comptes et de valider. Par défaut, "
-				"tous les comptes sont utilisés).";
+				description = _("This report shows the month's expenses sorted by payees."
+								"You will just have to choose the account(s) and validate. "
+								"By default, all accounts are in use.");
 			else
 				description = _("This report displays current month's outgoings sorted by payees. "
 								"You just need to select the account(s). By default all accounts are selected.");
@@ -303,15 +307,15 @@ static gboolean etats_onglet_report_export_change_format (GtkWidget *combo,
     switch (gtk_combo_box_get_active (GTK_COMBO_BOX(combo)))
     {
 	    case REPORT_EGSB:		/* EGSB */
-		extension = "egsb";
+		extension = (gchar*)"egsb";
 		break;
 
 	    case REPORT_HTML:		/* HTML */
-		extension = "html";
+		extension = (gchar*)"html";
 		break;
 
 	    case REPORT_CSV:		/* CSV */
-		extension = "csv";
+		extension = (gchar*)"csv";
 		break;
 
 	    default :
@@ -925,13 +929,9 @@ gboolean etats_onglet_ajoute_etat (void)
     {
 		case 0:
 		{
-			GrisbiWinEtat *w_etat;
-
-			w_etat = grisbi_win_get_w_etat ();
-
 			/*  Last month incomes and outgoings  */
 			if (w_etat->metatree_assoc_mode)
-				report_number = gsb_data_report_new ("Produits et Charges du dernier mois");
+				report_number = gsb_data_report_new (_("Last month products and expenses"));
 			else
 				report_number = gsb_data_report_new (_("Last month incomes and outgoings"));
 
@@ -958,10 +958,6 @@ gboolean etats_onglet_ajoute_etat (void)
 
 		case 1:
 		{
-			GrisbiWinEtat *w_etat;
-
-			w_etat = grisbi_win_get_w_etat ();
-
 			/*  Current month incomes and outgoings */
 			if (w_etat->metatree_assoc_mode)
 				report_number = gsb_data_report_new ("Produits et Charges du mois en cours");
@@ -1084,10 +1080,6 @@ gboolean etats_onglet_ajoute_etat (void)
 
 		case 5:
 		{
-			GrisbiWinEtat *w_etat;
-
-			w_etat = grisbi_win_get_w_etat ();
-
 			/* Monthly outgoings by payee */
 			if (w_etat->metatree_assoc_mode)
 				report_number = gsb_data_report_new ("Charges mensuelles par Tiers");
@@ -1251,7 +1243,7 @@ void etats_onglet_efface_etat (void)
 
     hint = g_strdup_printf (_("Delete report \"%s\"?"),
                              gsb_data_report_get_report_name (current_report_number));
-    answer = question_yes_no (_("This will irreversibly remove this report.  "
+    answer = dialogue_yes_no (_("This will irreversibly remove this report.  "
                                  "There is no undo for this."),
                                hint, GTK_RESPONSE_NO);
     g_free (hint);
@@ -1345,6 +1337,68 @@ void etats_onglet_update_gui_to_report (gint report_number)
         gtk_widget_show (gtk_bin_get_child (GTK_BIN (scrolled_window_etat)));
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void etats_onglet_create_search_report (void)
+{
+	gchar *report_name;
+	gchar *tmp_str;
+    gint report_number;
+	GrisbiWinRun *w_run;
+
+	w_run = grisbi_win_get_w_run ();
+
+	/* Search */
+	report_number = gsb_data_report_new (_("Search"));
+	gsb_data_report_set_search_report (report_number);
+
+	/* set empty report */
+	w_run->empty_report = TRUE;
+
+	/* le classement de base est 1-2-3-4-5-6 (cf structure.h) */
+	etats_onglet_set_classement_base (report_number);
+
+	/* les devises sont à 1 (euro) */
+	etats_onglet_set_devises (report_number);
+
+	/* Others parameters */
+	gsb_data_report_set_show_report_transactions (report_number, 1);
+	gsb_data_report_set_show_report_date (report_number, 1);
+	gsb_data_report_set_show_report_value_date (report_number, 1);
+	gsb_data_report_set_show_report_payee (report_number, 1);
+	gsb_data_report_set_show_report_category (report_number, 1);
+	gsb_data_report_set_show_report_sub_category (report_number, 1);
+	gsb_data_report_set_show_report_note (report_number, 1);
+	gsb_data_report_set_show_report_financial_year (report_number, 1);
+	gsb_data_report_set_report_can_click (report_number, 1);
+	gsb_data_report_set_date_type (report_number, 4);
+	gsb_data_report_set_column_title_show (report_number, 1);
+	gsb_data_report_set_report_can_click (report_number, 1);
+
+	/* name report */
+	tmp_str = utils_str_itoa (search_number);
+	report_name = g_strconcat (_("Searching"), " ", tmp_str, NULL);
+	gsb_data_report_set_report_name ( report_number, report_name);
+	g_free (report_name);
+	g_free (tmp_str);
+	search_number++;
+
+	/* Add an entry in navigation pane. */
+    gsb_gui_navigation_add_report (report_number);
+    etats_onglet_update_gui_to_report (report_number);
+
+	if (w_run->no_show_prefs == FALSE)
+		etats_config_personnalisation_etat ();
+
+	etats_onglet_force_fill_reports_list (GTK_NOTEBOOK (notebook_etats));
+	w_run->empty_report = FALSE;
+}
+
 /**
  *
  *
