@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2007 Cédric Auger    (cedric@grisbi.org)         */
 /*          2006-2007 Benjamin Drieu (bdrieu@april.org)                       */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -651,7 +651,7 @@ static GtkWidget *create_export_account_resume_page (struct ExportedAccount *acc
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
     gtk_container_set_border_width (GTK_CONTAINER(vbox), BOX_BORDER_WIDTH);
 
-    tmpstr = make_pango_attribut ("size=\"x-large\"",
+    tmpstr = dialogue_make_pango_attribut ("size=\"x-large\"",
                         g_strdup_printf (_("Export of: %s"),
                         gsb_data_account_get_name (account->account_nb)));
 
