@@ -64,7 +64,7 @@
 /*START_STATIC*/
 static GtkCssProvider *	css_provider = NULL;    /* css provider */
 static gchar *			css_data = NULL;		/* fichier css sous forme de string */
-static gboolean			darkmode = FALSE;		/* use to set darkmode from command_line */
+gboolean				darkmode = FALSE;		/* use to set darkmode from command_line */
 
 static GrisbiWin *grisbi_app_create_window (GrisbiApp *app,
                                             GdkScreen *screen);
@@ -752,13 +752,6 @@ static const GOptionEntry options[] =
 		N_("DEBUG")
     },
 
-	/* darkmode */
-	{
-		"darkmode", 'm', 0, G_OPTION_ARG_NONE, NULL,
-		N_("If present, force the use of a dark theme"),
-		NULL
-	},
-
 	/* New instance */
 /*	{
 		"standalone", 's', 0, G_OPTION_ARG_NONE, NULL,
@@ -766,14 +759,6 @@ static const GOptionEntry options[] =
 		NULL
 	},
 */
-#ifdef __APPLE__
-    /* communicate with the macOS launcher */
-    {
-        "launcher", '\0', 0, G_OPTION_ARG_STRING, NULL,
-        "macOS launcher synchronisation pipe",
-        "FILENAME"
-    },
-#endif
 	/* collects file arguments */
 	{
 		G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, NULL,
@@ -829,9 +814,6 @@ static gboolean grisbi_app_cmdline (GApplication *application,
 	GVariantDict *v_options;
 	gchar *tmp_str = NULL;
 	const gchar **remaining_args;
-#ifdef __APPLE__
-    gchar *launcher_str = NULL;
-#endif
 
 	priv = grisbi_app_get_instance_private (GRISBI_APP (application));
 
@@ -844,9 +826,6 @@ static gboolean grisbi_app_cmdline (GApplication *application,
 	g_variant_dict_lookup (v_options, "new-window", "b", &priv->new_window);
 	g_variant_dict_lookup (v_options, "debug", "s", &tmp_str);
 	g_variant_dict_lookup (v_options, "d", "s", &tmp_str);
-#ifdef __APPLE__
-    g_variant_dict_lookup (v_options, "launcher", "s", &launcher_str);
-#endif
 
     /* Parse filenames */
 	if (g_variant_dict_lookup (v_options, G_OPTION_REMAINING, "^a&ay", &remaining_args))
@@ -892,27 +871,6 @@ static gboolean grisbi_app_cmdline (GApplication *application,
 		}
 #endif
 
-#ifdef __APPLE__
-    if (launcher_str && strlen(launcher_str) > 0)
-    {
-        FILE *fd;
-        fd = fopen(launcher_str, "w");
-        if (fd == NULL)
-        {
-            char *error;
-            asprintf(&error, "%s: %s", launcher_str, strerror(errno));
-            important_debug(error);
-            free(error);
-        }
-        else
-        {
-            char ok[] = "ok\n";
-            fwrite(ok, sizeof(ok), 1, fd);
-            fclose(fd);
-        }
-    }
-#endif
-
     if (priv->new_window)
 		grisbi_app_create_window (GRISBI_APP (application), NULL);
 
@@ -939,12 +897,6 @@ static gint grisbi_app_handle_local_options (GApplication *app,
         return 0;
     }
 
-	if (g_variant_dict_contains (v_options, "darkmode"))
-	{
-		darkmode = TRUE;
-		g_print ("darkmode is set\n");
-	}
-
     return -1;
 }
 
