@@ -176,7 +176,7 @@ static void grisbi_conf_clean_config (GrisbiAppConf *a_conf)
 	/* settings_scheduled */
     a_conf->balances_with_scheduled = TRUE;
     a_conf->execute_scheduled_of_month = FALSE;
-	a_conf->last_selected_scheduler = TRUE;
+	a_conf->select_scheduled_in_list = TRUE;
     a_conf->nb_days_before_scheduled = 0;
     a_conf->scheduler_fixed_day = 1;
     a_conf->scheduler_set_fixed_day = FALSE;
@@ -203,6 +203,7 @@ gboolean grisbi_conf_load_app_config (void)
 	gchar *tmp_path;
 	gchar *tmp_str;
     gint i;
+	gint tmp_number;
 	ConditionalMsg *warning;
 	GrisbiAppConf *a_conf;
 
@@ -371,10 +372,16 @@ gboolean grisbi_conf_load_app_config (void)
     }
 	grisbi_app_set_recent_files_array (recent_array);
 
-	a_conf->nb_max_derniers_fichiers_ouverts = g_key_file_get_integer (config,
-																	   "File",
-																	   "nb-max-derniers-fichiers-ouverts",
-																	   NULL);
+	tmp_number = g_key_file_get_integer (config,
+									     "File",
+									     "nb-max-derniers-fichiers-ouverts",
+									     NULL);
+
+	/* reinitialise nb_max_derniers_fichiers_ouverts si tmp_number = 0 */
+	if (tmp_number == 0)
+		tmp_number = 3;
+	a_conf->nb_max_derniers_fichiers_ouverts = tmp_number;
+
 	a_conf->sauvegarde_auto = g_key_file_get_boolean (config,
 													  "File",
 													  "sauvegarde-auto",
@@ -437,12 +444,11 @@ gboolean grisbi_conf_load_app_config (void)
 									 "General",
 									 "current-theme",
 									 NULL);
-	if (tmp_str == NULL || strlen (tmp_str) == 0)
-    {
-        a_conf->current_theme = g_strdup ("null");
-    }
-    else
+	if (tmp_str && strlen (tmp_str) > 0)
     {
+		if (a_conf->current_theme)
+			g_free (a_conf->current_theme);
+
         a_conf->current_theme = g_strdup (tmp_str);
         g_free (tmp_str);
     }
@@ -669,9 +675,9 @@ gboolean grisbi_conf_load_app_config (void)
 							"Scheduled",
                         	"execute-scheduled-of-month",
                         	NULL);
-	a_conf->last_selected_scheduler = g_key_file_get_boolean (config,
+	a_conf->select_scheduled_in_list = g_key_file_get_boolean (config,
 							"Scheduled",
-							"last-selected-scheduler",
+							"select-scheduled-in-list",
 							NULL);
     a_conf->nb_days_before_scheduled = g_key_file_get_integer  (config,
 							"Scheduled",
@@ -1106,8 +1112,8 @@ gboolean grisbi_conf_save_app_config (void)
                         	a_conf->execute_scheduled_of_month);
     g_key_file_set_boolean (config,
 							"Scheduled",
-							"last-selected-scheduler",
-							a_conf->last_selected_scheduler);
+							"select-scheduled-in-list",
+							a_conf->select_scheduled_in_list);
 
     g_key_file_set_integer  (config,
 							"Scheduled",
