@@ -1,3 +1,5 @@
+#ifndef USE_CONFIG_FILE
+
 #ifndef __GRISBI_SETTINGS_H__
 #define __GRISBI_SETTINGS_H__
 
@@ -34,11 +36,14 @@ struct _GrisbiSettingsClass
 
 /* START_DECLARATION */
 GType               grisbi_settings_get_type			(void) G_GNUC_CONST;
-GrisbiSettings *	grisbi_settings_get					(void);
-GSettings *         grisbi_settings_get_settings		(gint schema);
+GrisbiSettings *	grisbi_settings_load_app_config		(void);
 void                grisbi_settings_save_app_config		(void);
+
+/* sert au changement de système de configuration PROVISOIRE */
+void				grisbi_settings_save_in_config_file (void);
 /* END_DECLARATION */
 
 G_END_DECLS
 
 #endif  /* __GRISBI_SETTINGS_H__ */
+#endif	/* USE_CONFIG_FILE */
