@@ -4,7 +4,7 @@
 /*          2004-2009 Benjamin Drieu (bdrieu@april.org)                       */
 /*                 2009-2017 Pierre Biava (grisbi@pierre.biava.name)          */
 /*      2009 Thomas Peel (thomas.peel@live.fr)                                */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -198,6 +198,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     GtkWidget *onglet, *vbox, *scrolled_window, *hbox, *vbox2;
     GtkWidget *label, *scrolled_window_text, *paddingbox;
     GtkSizeGroup *size_group;
+	GSList *list;
 
     devel_debug ( NULL );
 
@@ -261,13 +262,15 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     /* create the list of the kind of account combobox */
-    detail_type_compte = gsb_autofunc_combobox_new ( gsb_account_property_create_combobox_list (),
+	list = gsb_account_property_create_combobox_list ();
+    detail_type_compte = gsb_autofunc_combobox_new ( list,
                         0,
                         G_CALLBACK (gsb_account_property_changed),
                         GINT_TO_POINTER (PROPERTY_KIND),
                         G_CALLBACK (gsb_data_account_set_kind),
                         0 );
     gtk_box_pack_start ( GTK_BOX(hbox), detail_type_compte, TRUE, TRUE, 0);
+	g_slist_free (list);
 
     /* create the currency line */
     hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
@@ -681,7 +684,7 @@ gboolean gsb_account_property_changed_bank_label ( GtkWidget *combobox,
     if (!combobox)
         return FALSE;
 
-    bank_number = gsb_bank_list_get_bank_number (combobox);
+    bank_number = gsb_bank_combo_list_get_bank_number (combobox);
     if ( bank_number == 0 )
         gtk_widget_set_sensitive ( GTK_WIDGET (edit_bank_button), FALSE );
     else
@@ -827,7 +830,7 @@ gboolean gsb_account_property_change_currency ( GtkWidget *combobox,
     tmpstr = g_strdup_printf ( _("You are changing the currency of the account, do you want to change the currency of the transactions too?\n(yes will change all the transactions currency from %s to %s, all the transactions with another currency will stay the same).\n\nArchived and reconcilied transactions will be left unmodified."),
 				      gsb_data_currency_get_name (account_currency_number),
 				      gsb_data_currency_get_name (new_currency_number));
-    result = question_yes_no (tmpstr, _("Change the transactions currency"),
+    result = dialogue_yes_no (tmpstr, _("Change the transactions currency"),
 				    GTK_RESPONSE_NO );
     g_free ( tmpstr );
 
@@ -927,7 +930,7 @@ void gsb_account_property_iban_insert_text ( GtkEditable *entry,
     gchar *iban;
     gint nbre_char;
 
-    iban = g_utf8_strup (text, length);
+	iban = g_utf8_strup (text, length);
 
     /* on bloque l'appel de la fonction */
     g_signal_handlers_block_by_func ( G_OBJECT (entry),
@@ -950,7 +953,10 @@ void gsb_account_property_iban_insert_text ( GtkEditable *entry,
     /* on contrôle l'existence d'un modèle pour le numéro IBAN */
     if ( g_utf8_strlen (iban, -1) >= 2 )
     {
-        if ( g_utf8_collate ( s_iban -> locale, g_strndup (iban, 2)) != 0)
+		gchar *free_str;
+
+		free_str = g_strndup (iban, 2);
+        if ( g_utf8_collate ( s_iban -> locale, free_str) != 0)
         {
             s_iban = gsb_account_property_iban_get_struc ( iban );
 
@@ -960,6 +966,7 @@ void gsb_account_property_iban_insert_text ( GtkEditable *entry,
                 nbre_char = s_iban -> nbre_char + (s_iban -> nbre_char / 4);
             gtk_entry_set_max_length ( GTK_ENTRY (entry), nbre_char );
         }
+		g_free (free_str);
     }
 
     g_free ( iban );
@@ -1131,6 +1138,7 @@ gboolean gsb_account_property_iban_focus_out_event ( GtkWidget *entry,
 gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
 {
     struct Iso13616Iban *s_iban;
+	gchar *free_str;
     gchar *model;
     gchar *tmpstr;
     gchar *ptr_1;
@@ -1150,7 +1158,7 @@ gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
     g_signal_handlers_block_by_func ( G_OBJECT ( bank_list_combobox ),
                         G_CALLBACK ( gsb_account_property_changed_bank_label ),
                         NULL );
-    gsb_bank_list_set_bank ( bank_list_combobox, bank_number );
+    gsb_bank_combo_list_set_bank ( bank_list_combobox, bank_number );
     g_signal_handlers_unblock_by_func ( G_OBJECT ( bank_list_combobox ),
                         G_CALLBACK ( gsb_account_property_changed_bank_label ),
                         NULL );
@@ -1162,7 +1170,9 @@ gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
         return FALSE;
     }
 
-    s_iban = gsb_account_property_iban_get_struc ( g_strndup (iban, 2) );
+	free_str = g_strndup (iban, 2);
+    s_iban = gsb_account_property_iban_get_struc (free_str);
+	g_free (free_str);
 
     /* on affiche les données banquaires pour un IBAN sans modèle */
     if ( g_strcmp0 (s_iban -> locale, "XX") == 0 )
@@ -1176,7 +1186,11 @@ gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
     model = my_strdelimit ( s_iban -> iban, " -", "" );
     tmpstr = my_strdelimit ( iban, " -", "" );
     if ( g_utf8_strlen (model, -1) != g_utf8_strlen (tmpstr, -1) )
+	{
+		g_free (tmpstr);
+
         return FALSE;
+	}
 
     code = g_malloc0 ( 36 * sizeof (gunichar) );
 
@@ -1233,9 +1247,12 @@ gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
     }
     else
 	{
-        code = g_strdup ( "" );
-		gtk_label_set_text ( GTK_LABEL (label_guichet), code );
+		gchar *tmp_str2;
+
+		tmp_str2 = g_strdup ( "" );
+		gtk_label_set_text ( GTK_LABEL (label_guichet), tmp_str2);
 		gtk_widget_show ( label_guichet );
+		g_free (tmp_str2);
 	}
 
     /* set bank_account_number */
@@ -1268,7 +1285,10 @@ gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
         code = g_utf8_strncpy ( code, ptr_1, (pos_char_2 - pos_char_1) + 1 );
     }
     else
+	{
+		g_free (code);
         code = g_strdup ( "" );
+	}
     gtk_label_set_text ( GTK_LABEL (label_cle_compte), code );
     gtk_widget_show ( label_cle_compte );
 
@@ -1290,10 +1310,17 @@ void gsb_account_property_iban_set_iban ( const gchar *iban )
 {
     gint position = 0;
 
+	g_signal_handlers_block_by_func (G_OBJECT (detail_IBAN),
+									 G_CALLBACK (gsb_account_property_iban_insert_text),
+									 bank_list_combobox);
+
     gtk_editable_delete_text ( GTK_EDITABLE (detail_IBAN), 0, -1 );
     if ( iban && strlen (iban) > 0 )
         gtk_editable_insert_text ( GTK_EDITABLE (detail_IBAN),
                             iban, -1, &position );
+	g_signal_handlers_unblock_by_func (G_OBJECT (detail_IBAN),
+									   G_CALLBACK (gsb_account_property_iban_insert_text),
+									   bank_list_combobox);
 }
 
 /**
@@ -1459,7 +1486,7 @@ gint gsb_account_property_iban_control_iban ( gchar *iban )
     while ( gstring -> len > 0 )
     {
         substr = g_strndup ( gstring -> str, 9 );
-        lnum = ( gulong ) utils_str_safe_strtod ( substr, NULL );
+        lnum = utils_str_safe_strtod ( substr, NULL );
         reste = lnum % 97;
 
         g_free ( substr );
@@ -1570,6 +1597,26 @@ gboolean gsb_account_property_focus_out ( GtkWidget *widget,
 
     return FALSE;
 }
+
+/**
+ * retour le bank_combobox used in prefs_page_bank
+ *
+ * \param
+ *
+ * \return
+ **/
+GtkWidget * gsb_account_property_get_bank_list_combobox (void)
+{
+	return bank_list_combobox;
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
