@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -39,7 +39,6 @@
 #include "gsb_account.h"
 #include "gsb_assistant.h"
 #include "gsb_bank.h"
-#include "gsb_currency_config.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_bank.h"
@@ -80,8 +79,6 @@ enum FirstAccountAssistantPage
 static GtkWidget *account_combobox_currency = NULL;
 static GtkWidget *account_combobox_bank = NULL;
 static GtkWidget *account_entry_initial_amount = NULL;
-static GtkWidget *account_entry_name = NULL;
-
 
 /**
  * this function is called to launch the account assistant
@@ -127,13 +124,16 @@ GtkResponseType gsb_assistant_account_run ( void )
 
     if (return_value == GTK_RESPONSE_APPLY)
     {
-	/* Ok, we create the new account */
-	gsb_account_new ( GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT (assistant), "account_kind")),
-			  gsb_currency_get_currency_from_combobox (account_combobox_currency),
-			  gsb_bank_list_get_bank_number (account_combobox_bank),
-			  utils_real_get_from_string (gtk_entry_get_text (GTK_ENTRY (account_entry_initial_amount))),
-			  gtk_entry_get_text (GTK_ENTRY (account_entry_name)),
-              new_icon );
+		GtkWidget *account_entry_name;
+
+		/* Ok, we create the new account */
+		account_entry_name = g_object_get_data (G_OBJECT (assistant), "account_entry_name");
+		gsb_account_new ( GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT (assistant), "account_kind")),
+				  gsb_currency_get_currency_from_combobox (account_combobox_currency),
+				  gsb_bank_combo_list_get_bank_number (account_combobox_bank),
+				  utils_real_get_from_string (gtk_entry_get_text (GTK_ENTRY (account_entry_initial_amount))),
+				  gtk_entry_get_text (GTK_ENTRY (account_entry_name)),
+				  new_icon );
         result = TRUE; /* assistant was not cancelled */
     }
 
@@ -224,6 +224,8 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
 {
     GtkWidget *page, *label, *button, *table;
     GtkWidget *image;
+    GdkPixbuf *pixbuf;
+
     struct lconv *locale = gsb_locale_get_locale ( );
 
     page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
@@ -245,9 +247,9 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
      * this would confuse US folks while rest of the world is used to
      * configure stuff to their locale.  */
     if ( ! gsb_data_currency_get_default_currency () &&
-	 ! gsb_currency_config_create_currency_from_iso4217list ( locale -> int_curr_symbol ) )
+	 ! gsb_data_currency_new_from_iso4217_list ( locale -> int_curr_symbol ) )
     {
-	gsb_currency_config_create_currency_from_iso4217list ( "USD" );
+	gsb_data_currency_new_from_iso4217_list ( "USD" );
     }
 
     /* create the currency combobox */
@@ -258,7 +260,7 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
     button = gtk_button_new_with_label (_("Add/Change..."));
     g_signal_connect ( G_OBJECT (button),
 		       "clicked",
-		       G_CALLBACK (gsb_currency_config_add_currency_set_combobox),
+		       G_CALLBACK (gsb_currency_add_currency_set_combobox),
 		       account_combobox_currency );
     gtk_grid_attach (GTK_GRID (table), button, 2, 0, 1, 1);
 
@@ -271,11 +273,11 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
 
     if ( gsb_data_bank_max_number() != 0 )
     {
-	gsb_bank_list_set_bank ( account_combobox_bank, 1 );
+	gsb_bank_combo_list_set_bank ( account_combobox_bank, 1 );
     }
     else
     {
-	gsb_bank_list_set_bank ( account_combobox_bank, 0 );
+	gsb_bank_combo_list_set_bank ( account_combobox_bank, 0 );
     }
     gtk_grid_attach (GTK_GRID (table), account_combobox_bank, 1, 1, 1, 1);
 
@@ -291,8 +293,9 @@ static GtkWidget *gsb_assistant_account_page_3 ( GtkWidget *assistant )
     /* Récupération de l'icône par défaut */
     button = gtk_button_new ( );
     gtk_widget_set_size_request ( button, 80, 80 );
-    image = gtk_image_new_from_pixbuf (
-                gsb_data_account_get_account_standard_pixbuf ( 0 ) );
+	pixbuf = gsb_data_account_get_account_standard_pixbuf (0);
+    image = gtk_image_new_from_pixbuf (pixbuf);
+	g_object_unref (G_OBJECT (pixbuf));
     gtk_button_set_image ( GTK_BUTTON ( button ), image);
     gtk_button_set_relief ( GTK_BUTTON ( button ), GTK_RELIEF_NORMAL );
     gtk_grid_attach (GTK_GRID (table), button, 3, 0, 1, 3);
@@ -325,6 +328,7 @@ static GtkWidget *gsb_assistant_account_page_finish ( GtkWidget *assistant )
     GtkWidget *vbox;
     GtkWidget *label;
     GtkWidget *hbox;
+	GtkWidget *account_entry_name;
 
     page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
@@ -382,11 +386,11 @@ static gboolean gsb_assistant_account_enter_page_finish ( GtkWidget * assistant,
     switch ( account_type )
     {
 	case GSB_TYPE_BANK:
-	    if ( gsb_bank_list_get_bank_number ( account_combobox_bank ) >= 0 )
+	    if ( gsb_bank_combo_list_get_bank_number ( account_combobox_bank ) >= 0 )
 	    {
 		const gchar * bank_name;
 
-		bank_name = gsb_data_bank_get_name ( gsb_bank_list_get_bank_number ( account_combobox_bank ) );
+		bank_name = gsb_data_bank_get_name ( gsb_bank_combo_list_get_bank_number ( account_combobox_bank ) );
 		/* Do not use a bank name if no bank is set or if its
 		 * name has not been changed. */
 		if ( bank_name && strcmp ( bank_name, _("New bank") ) )
@@ -430,6 +434,8 @@ gboolean gsb_assistant_account_toggled_kind_account ( GtkWidget *button,
 						      GtkWidget *assistant )
 {
     GtkWidget *bouton_icon, *image;
+    GdkPixbuf *pixbuf;
+
     KindAccount account_kind;
 
     account_kind = GPOINTER_TO_INT ( g_object_get_data
@@ -438,8 +444,9 @@ gboolean gsb_assistant_account_toggled_kind_account ( GtkWidget *button,
                 "account_kind", GINT_TO_POINTER ( account_kind ) );
 
     bouton_icon = g_object_get_data ( G_OBJECT (assistant), "bouton_icon" );
-    image = gtk_image_new_from_pixbuf (
-                gsb_data_account_get_account_standard_pixbuf ( account_kind ) );
+	pixbuf = gsb_data_account_get_account_standard_pixbuf (account_kind);
+    image = gtk_image_new_from_pixbuf (pixbuf);
+	g_object_unref (G_OBJECT (pixbuf));
     gtk_button_set_image ( GTK_BUTTON ( bouton_icon ), image);
     return FALSE;
 }
@@ -469,8 +476,9 @@ void gsb_assistant_account_change_account_icon ( GtkWidget *button, gpointer dat
     }
     else
     {
-    image = gtk_image_new_from_pixbuf ( pixbuf );
-        if ( image )
-            gtk_button_set_image ( GTK_BUTTON ( button ), image );
+		image = gtk_image_new_from_pixbuf ( pixbuf );
+		g_object_unref (G_OBJECT (pixbuf));
+		if ( image )
+			gtk_button_set_image ( GTK_BUTTON ( button ), image );
     }
 }
