@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2007 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2008-2009 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -37,7 +37,7 @@
 /*START_INCLUDE*/
 #include "gsb_assistant_archive.h"
 #include "etats_support.h"
-#include "grisbi_win.h"
+#include "grisbi_app.h"
 #include "gsb_assistant.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_data_archive.h"
@@ -130,17 +130,23 @@ GtkResponseType gsb_assistant_archive_run ( gboolean origin )
     gchar *tmpstr;
 
     if (origin)
-	/* come from check while opening file */
-	tmpstr = g_strdup_printf ( _("There are a lot of transactions in your file (%d) and it is advised not to keep more than about %d transactions unarchived.\n"
-				     "To increase speed, you should archive them "
-				     "(the current limit and the opening check-up can be changed in the Preferences)\n\n"
-				     "This assistant will guide you through the process of archiving transactions "
-				     "By default, Grisbi does not export any archive into separate files, "
-				     "it just mark transactions as archted and do not use them.\n\n"
-				     "You can still export them into a separate archive file if necessary.\n\n"
-				     "Press Cancel if you don't want make an archive now\n"),
-				   g_slist_length (gsb_data_transaction_get_transactions_list ()),
-				   conf.max_non_archived_transactions_for_check );
+	{
+		GrisbiAppConf *a_conf;
+
+		a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+
+		/* come from check while opening file */
+		tmpstr = g_strdup_printf ( _("There are a lot of transactions in your file (%d) and it is advised not to keep more than about %d transactions unarchived.\n"
+						 "To increase speed, you should archive them "
+						 "(the current limit and the opening check-up can be changed in the Preferences)\n\n"
+						 "This assistant will guide you through the process of archiving transactions "
+						 "By default, Grisbi does not export any archive into separate files, "
+						 "it just mark transactions as archted and do not use them.\n\n"
+						 "You can still export them into a separate archive file if necessary.\n\n"
+						 "Press Cancel if you don't want make an archive now\n"),
+					   g_slist_length (gsb_data_transaction_get_transactions_list ()),
+					   a_conf->max_non_archived_transactions_for_check );
+	}
     else
 	/* come by menu action */
 	tmpstr = my_strdup (_("This assistant will guide you through the process of archiving transactions "
@@ -826,11 +832,11 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
             string = NULL;
 
             if ( !strlen ( gtk_entry_get_text ( GTK_ENTRY ( initial_date ) ) ) )
-                string = make_red ( _("Please fill the initial date."));
+                string = dialogue_make_red ( _("Please fill the initial date."));
             if ( !string
                 &&
                 !strlen ( gtk_entry_get_text ( GTK_ENTRY ( final_date ) ) ) )
-                string = make_red ( _("Please fill the final date.") );
+                string = dialogue_make_red ( _("Please fill the final date.") );
             if ( !string
                  &&
                  init_gdate
@@ -838,23 +844,23 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
                  final_gdate
                  &&
                  g_date_compare (init_gdate, final_gdate) > 0 )
-                string = make_red (_("The initial date is after the final date."));
+                string = dialogue_make_red (_("The initial date is after the final date."));
             if ( !string
                  &&
                  !init_gdate)
-                string = make_red (_("The initial date is not valid."));
+                string = dialogue_make_red (_("The initial date is not valid."));
             if ( !string
                  &&
                  !final_gdate )
-                string = make_red (_("The final date is not valid."));
+                string = dialogue_make_red (_("The final date is not valid."));
             if ( !string
                  &&
                  gsb_data_archive_get_from_date (init_gdate) )
-                string = make_red (_("The initial date belongs already to an archive."));
+                string = dialogue_make_red (_("The initial date belongs already to an archive."));
             if ( !string
                  &&
                  gsb_data_archive_get_from_date (final_gdate) )
-                string = make_red (_("The final date belongs already to an archive."));
+                string = dialogue_make_red (_("The final date belongs already to an archive."));
 
             if (string)
             {
@@ -898,12 +904,12 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
             fyear_number = gsb_fyear_get_fyear_from_combobox ( financial_year_button, NULL );
 
             if (!fyear_number)
-                string = make_red (_("Please choose a financial year."));
+                string = dialogue_make_red (_("Please choose a financial year."));
 
             if ( !string
              &&
              gsb_data_archive_get_from_fyear ( fyear_number ) )
-                string = make_red (_("There is already an archive for that financial year."));
+                string = dialogue_make_red (_("There is already an archive for that financial year."));
 
             if (string)
             {
@@ -939,7 +945,7 @@ static gboolean gsb_assistant_archive_update_labels ( GtkWidget *assistant )
             report_number = gsb_report_get_report_from_combobox (report_button);
 
             if (!report_number)
-                string = make_red (_("Please choose a report."));
+                string = dialogue_make_red (_("Please choose a report."));
 
             if (string)
             {
