@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2007 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -35,6 +35,7 @@
 
 /*START_INCLUDE*/
 #include "gsb_assistant_archive_export.h"
+#include "grisbi_app.h"
 #include "gsb_assistant.h"
 #include "export_csv.h"
 #include "gsb_data_archive.h"
@@ -149,9 +150,8 @@ static GtkWidget *gsb_assistant_archive_export_page_choose ( GtkWidget *assistan
     GtkWidget *vbox_page, *scrolled_window;
     GtkWidget *paddingbox;
     GtkListStore *archive_model;
-    gchar *titles[] = {
-	"", _("Name"), _("Initial date"), _("Final date"), _("Financial year"), _("Report name")
-    };
+    const gchar *titles[] = {" ", N_("Name"), N_("Initial date"), N_("Final date"),
+							 N_("Financial year"), N_("Report name")};
     gfloat alignment[] = {
 	COLUMN_CENTER, COLUMN_LEFT, COLUMN_CENTER, COLUMN_CENTER , COLUMN_CENTER, COLUMN_CENTER
     };
@@ -201,7 +201,7 @@ static GtkWidget *gsb_assistant_archive_export_page_choose ( GtkWidget *assistan
 					  GTK_TREE_VIEW_COLUMN_AUTOSIZE );
 	gtk_tree_view_column_set_alignment ( column,
 					     alignment[i] );
-	gtk_tree_view_column_set_title ( column, titles[i] );
+	gtk_tree_view_column_set_title (column, gettext (titles[i]));
 	gtk_tree_view_column_set_expand ( column, TRUE );
 	gtk_tree_view_column_set_resizable ( column,
 					     TRUE );
@@ -358,7 +358,9 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
     const gchar *export_name;
     gboolean success = FALSE;
     gchar* tmpstr;
+	GrisbiAppConf *a_conf;
 
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
     model = gtk_tree_view_get_model (GTK_TREE_VIEW (archive_export_treeview));
     archive_number = gsb_assistant_archive_export_get_selected_archive (model);
 
@@ -412,7 +414,7 @@ static gboolean gsb_assistant_archive_switch ( GtkWidget *assistant,
             }
 		    success = gsb_file_util_test_overwrite (export_name)
 			&&
-			gsb_file_save_save_file ( export_name, conf.compress_backup, archive_number);
+			gsb_file_save_save_file ( export_name, a_conf->compress_backup, archive_number);
 		    break;
 
 		case 1:
