@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2007 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2008 Benjamin Drieu (bdrieu@april.org)	      */
-/* 			http://www.grisbi.org				      */
+/* 			https://www.grisbi.org				      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -40,18 +40,22 @@
 #include "gsb_automem.h"
 #include "gsb_bank.h"
 #include "gsb_category.h"
-#include "gsb_currency_config.h"
+#include "gsb_currency_popup.h"
 #include "gsb_currency.h"
+#include "gsb_data_currency.h"
 #include "gsb_data_form.h"
 #include "gsb_dirs.h"
 #include "gsb_file.h"
 #include "gsb_select_icon.h"
 #include "import.h"
 #include "parametres.h"
+#include "prefs_page_bank.h"
 #include "structures.h"
 #include "traitement_variables.h"
 #include "utils.h"
+#include "utils_prefs.h"
 #include "utils_str.h"
+#include "widget_currency_popup.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -105,6 +109,7 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
 					 gboolean import )
 {
     GtkWidget *assistant;
+    GdkPixbuf *pixbuf;
     GtkTreeIter iter;
 	GtkTreeSelection *selection;
 	GtkTreeView *tree_view;
@@ -214,11 +219,11 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
 		gtk_tree_model_get (model,
 							&iter,
 							CURRENCY_NAME_COLUMN, &currency_name,
-							CURRENCY_ISO_CODE_COLUMN, &currency_iso_code,
+							CURRENCY_CODE_ISO_COLUMN, &currency_iso_code,
 							CURRENCY_NICKNAME_COLUMN, &currency_nickname,
 							CURRENCY_FLOATING_COLUMN, &currency_floating,
 							-1);
-		gsb_currency_config_create_currency (currency_name,
+		gsb_data_currency_new_with_data (currency_name,
 											 currency_nickname,
 											 currency_iso_code,
 											 currency_floating);
@@ -240,8 +245,9 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
     gtk_widget_destroy (assistant);
 
     /* initialise le logo accueil */
-    gsb_select_icon_set_logo_pixbuf (
-                        gsb_select_icon_get_default_logo_pixbuf ( ) );
+	pixbuf = gsb_select_icon_get_default_logo_pixbuf ();
+    gsb_select_icon_set_logo_pixbuf (pixbuf);
+    g_object_unref (G_OBJECT (pixbuf));
 
 	/* set the new filename */
 	grisbi_win_set_filename (NULL, nom_fichier_comptes);
@@ -356,7 +362,7 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
     {
         button = gsb_automem_checkbutton_new (_("Encrypt Grisbi file"),
 											  &w_etat->crypt_file,
-											  G_CALLBACK (gsb_gui_encryption_toggled),
+											  G_CALLBACK (utils_prefs_encryption_toggled),
 											  NULL);
         gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
                              FALSE, FALSE, 0 );
@@ -411,30 +417,26 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 static GtkWidget *gsb_assistant_file_page_3 ( GtkWidget *assistant )
 {
     GtkWidget *page;
+	GtkWidget *tree_view;
     GtkWidget *vbox;
 
-    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+	page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
-    vbox = new_vbox_with_title_and_icon ( _("Select base currency"),
-					  "gsb-currencies-32.png" );
-    gtk_box_pack_start ( GTK_BOX (page),
-			 vbox,
-			 TRUE, TRUE, 0 );
+	vbox = gsb_popup_list_iso_4217_new (page, NULL);
 
     /* set up the menu */
-    currency_list_box = gsb_currency_config_create_box_popup (NULL);
-    gtk_box_pack_start ( GTK_BOX (vbox),
-			 currency_list_box,
-			 TRUE, TRUE, 0 );
+     currency_list_box = g_object_get_data (G_OBJECT (vbox), "w_currency_popup" );
 
     /* Select default currency. */
-    gtk_tree_model_foreach ( GTK_TREE_MODEL(g_object_get_data ( G_OBJECT(currency_list_box), "model" )),
-			     (GtkTreeModelForeachFunc) gsb_currency_config_select_default,
-			     g_object_get_data ( G_OBJECT(currency_list_box), "tree_view" ) );
+	tree_view = g_object_get_data (G_OBJECT (vbox), "tree_view" );
+    gtk_tree_model_foreach (GTK_TREE_MODEL (gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view))),
+										   (GtkTreeModelForeachFunc) gsb_popup_list_select_default,
+										   tree_view);
 
     gtk_widget_show_all (page);
-    return page;
+
+	return page;
 }
 
 /**
@@ -486,10 +488,8 @@ static GtkWidget *gsb_assistant_file_page_5 ( GtkWidget *assistant )
     gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     /* the configuration page is very good, keep it */
-    bank_page = gsb_bank_create_page (TRUE, 130);
-    gtk_box_pack_start ( GTK_BOX (page),
-			 bank_page,
-			 TRUE, TRUE, 0 );
+    bank_page = GTK_WIDGET (prefs_page_bank_new (NULL));
+    gtk_box_pack_start (GTK_BOX (page), bank_page, TRUE, TRUE, 0);
 
     gtk_widget_show_all (page);
     return page;
