@@ -8,16 +8,16 @@
 
 
 /* START_DECLARATION */
-gboolean gsb_category_assistant_create_categories ( GtkWidget *assistant );
-GtkWidget *gsb_category_assistant_create_choice_page ( GtkWidget *assistant );
-gboolean gsb_category_update_combofix ( gboolean force );
+gboolean 	gsb_category_assistant_create_categories 	(GtkWidget *assistant);
+GtkWidget *	gsb_category_assistant_create_choice_page	(GtkWidget *assistant);
+gboolean 	gsb_category_update_combofix 				(gboolean force);
 /* END_DECLARATION */
 
 
 enum builtin_category_model_columns_enum {
     BUILTIN_CATEGORY_MODEL_FILENAME,
     BUILTIN_CATEGORY_MODEL_NAME,
-    BUILTIN_CATEGORY_MODEL_COLUMNS,
+    BUILTIN_CATEGORY_MODEL_COLUMNS
 };
 
 #endif
