@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2009-2015 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -90,7 +90,7 @@ struct _SubBudgetStruct
 /*START_STATIC*/
 static void _gsb_data_budget_free ( BudgetStruct* budget );
 static void _gsb_data_sub_budget_free ( SubBudgetStruct* sub_budget );
-static GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *budget_list,
+static GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *list_budget,
                         GSList *sub_budget_list );
 static gint gsb_data_budget_get_pointer_from_name_in_glist ( BudgetStruct *budget,
                         const gchar *name );
@@ -129,22 +129,24 @@ static BudgetStruct *empty_budget = NULL;
  *
  * \return FALSE
  * */
-gboolean gsb_data_budget_init_variables ( void )
+gboolean gsb_data_budget_init_variables (gboolean cleanup)
 {
     if ( budget_list )
     {
         g_slist_free_full ( budget_list, (GDestroyNotify) _gsb_data_budget_free );
-        budget_list = NULL;
     }
 
-    /* recreate the empty budget */
-    _gsb_data_budget_free ( empty_budget );
-    empty_budget = g_malloc0 ( sizeof ( BudgetStruct ));
-    empty_budget -> budget_name = g_strdup(_("No budget line"));
-
-    budget_buffer = NULL;
-    sub_budget_buffer = NULL;
+	if (cleanup)
+	{
+        budget_list = NULL;
+		/* recreate the empty budget */
+		_gsb_data_budget_free ( empty_budget );
+		empty_budget = g_malloc0 ( sizeof ( BudgetStruct ));
+		empty_budget -> budget_name = g_strdup(_("No budget line"));
 
+		budget_buffer = NULL;
+		sub_budget_buffer = NULL;
+	}
     return FALSE;
 }
 
@@ -980,13 +982,13 @@ GSList *gsb_data_budget_get_name_list ( gboolean set_debit,
  *
  * \return the new budget_list (normally shouldn't changed
  * */
-GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *budget_list,
+GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *list_budget,
                         GSList *sub_budget_list )
 {
     GSList *tmp_list;
 
     if (!sub_budget_list)
-	return budget_list;
+	return list_budget;
 
     tmp_list = sub_budget_list;
 
@@ -996,13 +998,12 @@ GSList *gsb_data_budget_append_sub_budget_to_list ( GSList *budget_list,
 
 	sub_budget = tmp_list -> data;
 
-	budget_list = g_slist_append ( budget_list,
-				       g_strconcat ( "\t",
-						     sub_budget -> sub_budget_name,
-						     NULL ));
+	list_budget = g_slist_append (list_budget,
+								  g_strconcat ("\t", sub_budget->sub_budget_name, NULL));
 	tmp_list = tmp_list -> next;
     }
-    return budget_list;
+
+    return list_budget;
 }
 
 
@@ -1420,7 +1421,7 @@ gchar * gsb_debug_duplicate_budget_check (void)
 {
     GSList * tmp;
     gint num_duplicate = 0;
-    gchar * output = "";
+    gchar * output = (gchar*)"";
 
     tmp = budget_list;
     while ( tmp )
