@@ -2,8 +2,8 @@
 /*                                                                            */
 /*     copyright (c)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2004-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*                      2008-2009 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*                      2008-2020 Pierre Biava (grisbi@pierre.biava.name)     */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -37,7 +37,6 @@
 #include "gsb_data_partial_balance.h"
 #include "dialog.h"
 #include "grisbi_app.h"
-#include "gsb_currency_config.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
@@ -51,6 +50,7 @@
 #include "utils.h"
 #include "structures.h"
 #include "utils_prefs.h"
+#include "utils_widgets.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -204,8 +204,8 @@ void gsb_partial_balance_fill_model ( GtkListStore *list_store )
     while ( list_tmp )
     {
         struct_partial_balance *partial_balance;
-        gchar *kind_str = "";
-        gchar *currency_str = "";
+        gchar *kind_str;
+        gchar *currency_str = (gchar*)"";
 
         partial_balance = list_tmp -> data;
 
@@ -242,6 +242,8 @@ void gsb_partial_balance_fill_model ( GtkListStore *list_store )
                     4, partial_balance -> partial_balance_number,
                     5, partial_balance -> colorise,
                     -1);
+		g_free (kind_str);
+
         list_tmp = list_tmp -> next;
     }
 }
@@ -397,17 +399,17 @@ dialog_return:
 
     if ( result == 1)
     {
-        const gchar *name, *liste_cptes;
+        const gchar *name, *new_liste_cptes;
         gint position;
 
         name = gtk_entry_get_text ( GTK_ENTRY ( entry_name ) );
-        liste_cptes = gtk_entry_get_text ( GTK_ENTRY ( entry_list ) );
+        new_liste_cptes = gtk_entry_get_text ( GTK_ENTRY ( entry_list ) );
 
-        if ( strlen ( name ) && strlen ( liste_cptes ) &&
-         g_utf8_strchr  ( liste_cptes, -1, ';' ) )
+        if ( strlen ( name ) && strlen (new_liste_cptes) &&
+         g_utf8_strchr  (new_liste_cptes, -1, ';' ) )
         {
             gsb_data_partial_balance_set_name ( partial_balance_number, name );
-            gsb_data_partial_balance_set_liste_cptes ( partial_balance_number, liste_cptes );
+            gsb_data_partial_balance_set_liste_cptes ( partial_balance_number, new_liste_cptes);
             gsb_data_partial_balance_init_from_liste_cptes ( partial_balance_number,
                         dialog );
             gsb_data_partial_balance_set_colorise ( partial_balance_number,
@@ -424,7 +426,7 @@ dialog_return:
             /* MAJ HOME_PAGE */
             gsb_gui_navigation_update_home_page ( );
         }
-        else if (  g_utf8_strchr ( liste_cptes, -1, ';' ) == NULL )
+        else if (  g_utf8_strchr (new_liste_cptes, -1, ';' ) == NULL )
         {
             dialogue_warning_hint ( _("You must select at least two accounts."),
                         _("Only one account is selected.") );
@@ -1091,7 +1093,13 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
         if (solde.mantissa < 0)
             color = g_strdup ("red");
         else
-            color = g_strdup ("blue");
+		{
+			gchar *str_to_free;
+
+			str_to_free = gsb_rgba_get_couleur_to_hexa_string ("text_gsetting_option_normal");
+            color = g_strdup (str_to_free);
+			g_free (str_to_free);
+		}
 
 		tmp_str = utils_real_get_string_with_currency (solde, partial_balance -> currency, TRUE);
         string = g_strdup_printf ("<span color=\"%s\">%s</span>", color, tmp_str);
@@ -1185,7 +1193,13 @@ gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_numbe
         if (solde.mantissa < 0)
             color = g_strdup ("red");
         else
-            color = g_strdup ("blue");
+		{
+			gchar *str_to_free;
+
+			str_to_free = gsb_rgba_get_couleur_to_hexa_string ("text_gsetting_option_normal");
+            color = g_strdup (str_to_free);
+			g_free (str_to_free);
+		}
 
 		tmp_str = utils_real_get_string_with_currency (solde, partial_balance -> currency, TRUE);
         string = g_strdup_printf ( "<span color=\"%s\">%s</span>", color, tmp_str);
@@ -1847,7 +1861,7 @@ gint gsb_partial_balance_request_currency ( GtkWidget *parent )
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, TRUE, TRUE, 0 );
 
-    combo_devise = gsb_currency_config_new_combobox ( &currency_nb, NULL );
+    combo_devise = gsb_currency_combobox_new ( &currency_nb, NULL );
     gtk_box_pack_start ( GTK_BOX ( hbox ), combo_devise, FALSE, FALSE, 10 );
 
     gtk_widget_show_all ( GTK_WIDGET ( dialog ) );
