@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2008 Benjamin Drieu (bdrieu@april.org)	      */
-/* 			http://www.grisbi.org				      */
+/* 			https://www.grisbi.org				      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -223,7 +223,6 @@ gint gsb_data_payment_get_number_by_name ( const gchar *name,
 {
     GSList *tmp_list;
     gint payment_number = 0 ;
-    gint compare;
 
     tmp_list = payment_list;
 
@@ -235,7 +234,7 @@ gint gsb_data_payment_get_number_by_name ( const gchar *name,
 
 	if ( payment -> account_number == account_number )
     {
-        if ( (compare = my_strcasecmp (  (gchar *)name, payment -> payment_name ) ) == 0 )
+        if ( my_strcasecmp ((gchar *) name, payment -> payment_name ) == 0 )
             return payment -> payment_number;
     }
 	tmp_list = tmp_list -> next;
@@ -947,6 +946,87 @@ gint gsb_data_payment_search_number_other_account_by_name ( gint payment_number,
 }
 
 
+/**
+ * This function looks for a method of payment which matches signe_type' and returns its number.
+ *
+ * \param account_number	The account to process.
+ * \param signe_type		A payment method sign to match against payment
+ *							methods of specified account.
+ *							(GSB_PAYMENT_NEUTRAL, GSB_PAYMENT_DEBIT, GSB_PAYMENT_CREDIT)
+ * \param exclude			A payment method that should not be checked,
+ *							as it may be the one which is to be removed.
+ *
+ * \return					The matching payment method number on success,
+ *							0 otherwise (for transfer).
+ **/
+gint gsb_data_payment_get_other_number_from_sign (gint account_number,
+                                                  gint signe_type,
+                                                  gint exclude_number)
+{
+    GSList *tmp_list;
+
+    tmp_list = gsb_data_payment_get_payments_list ();
+    while (tmp_list)
+    {
+		gint payment_number;
+
+		payment_number = gsb_data_payment_get_number (tmp_list -> data);
+
+		if (gsb_data_payment_get_account_number (payment_number) == account_number
+		    && payment_number != exclude_number
+		    && gsb_data_payment_get_sign (payment_number) == signe_type)
+		{
+			return payment_number;
+		}
+
+		tmp_list = tmp_list -> next;
+    };
+
+    /* Defaults to first method_ptr, whatever it may be */
+    return 0;
+}
+
+/**
+ *
+ *
+ * \param
+ * \param
+ * \param
+ *
+ * \return
+ **/
+void gsb_data_payment_change_default_payment_method (gint payment_number,
+                                                     gint account_number)
+{
+	switch (gsb_data_payment_get_sign (payment_number))
+	{
+		case GSB_PAYMENT_DEBIT:
+			if ( gsb_data_account_get_default_debit (account_number) == payment_number)
+			{
+				gsb_data_account_set_default_debit (account_number,
+													gsb_data_payment_get_other_number_from_sign
+													(account_number, GSB_PAYMENT_DEBIT, payment_number));
+			}
+			break;
+
+		case GSB_PAYMENT_CREDIT:
+			if ( gsb_data_account_get_default_credit (account_number) == payment_number)
+			{
+				gsb_data_account_set_default_credit (account_number,
+													 gsb_data_payment_get_other_number_from_sign
+													 (account_number, GSB_PAYMENT_CREDIT, payment_number));
+			}
+			break;
+	}
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
