@@ -84,7 +84,7 @@ gint 		gsb_data_report_get_payee_show_name 						(gint report_number);
 gint 		gsb_data_report_get_payee_show_payee_amount 				(gint report_number);
 gint 		gsb_data_report_get_payee_used 								(gint report_number);
 gint 		gsb_data_report_get_period_split 							(gint report_number);
-gint 		gsb_data_report_get_period_split_day 						(gint report_number);
+GDateWeekday	gsb_data_report_get_period_split_day 						(gint report_number);
 gint 		gsb_data_report_get_period_split_type 						(gint report_number);
 GDate *		gsb_data_report_get_personal_date_end 						(gint report_number);
 GDate *		gsb_data_report_get_personal_date_start						(gint report_number);
@@ -93,6 +93,7 @@ gint 		gsb_data_report_get_report_can_click 						(gint report_number);
 GSList *	gsb_data_report_get_report_list 							(void);
 gchar *		gsb_data_report_get_report_name 							(gint report_number);
 gint 		gsb_data_report_get_report_number 							(gpointer report_pointer);
+gboolean	gsb_data_report_get_search_report							(gint report_number);
 gint 		gsb_data_report_get_show_m 									(gint report_number);
 gint 		gsb_data_report_get_show_p 									(gint report_number);
 gint 		gsb_data_report_get_show_r 									(gint report_number);
@@ -127,7 +128,7 @@ gboolean 	gsb_data_report_init_variables 								(void);
 gint 		gsb_data_report_max_number 									(void);
 gboolean 	gsb_data_report_move_report 								(gint report_number,
 																		 gint dest_report_number);
-gint 		gsb_data_report_new 										(gchar *name);
+gint 		gsb_data_report_new 										(const gchar *name);
 gint 		gsb_data_report_new_with_number 							(gint number);
 void 		gsb_data_report_renum_account_number_0 						(gint new_account_number);
 gboolean 	gsb_data_report_remove 										(gint no_report);
@@ -245,6 +246,7 @@ gboolean 	gsb_data_report_set_report_can_click 						(gint report_number,
                         												 gint report_can_click);
 gboolean 	gsb_data_report_set_report_name 							(gint report_number,
                         												 const gchar *report_name);
+void		gsb_data_report_set_search_report							(gint report_number);
 gboolean 	gsb_data_report_set_show_m 									(gint report_number,
                         												 gint show_m);
 gboolean 	gsb_data_report_set_show_p 									(gint report_number,
