@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*     Copyright (C)	2004-2005 Alain Portal (aportal@univ-montp2.fr)	      */
 /*                  	2006-2006 Benjamin Drieu (bdrieu@april.org)	          */
-/*			http://www.grisbi.org   			                              */
+/*			https://www.grisbi.org/  			                              */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -113,7 +113,7 @@ static void gsb_debug_add_report_page (GtkWidget *assistant,
     gtk_container_add (GTK_CONTAINER (scrolled_window), vbox);
 
     label = gtk_label_new (NULL);
-    tmp_str = g_strconcat (make_pango_attribut ("size=\"larger\" weight=\"bold\"", _(test->name)),
+    tmp_str = g_strconcat (dialogue_make_pango_attribut ("size=\"larger\" weight=\"bold\"", _(test->name)),
 						   "\n\n",
 						   summary,
 						   NULL);
@@ -129,8 +129,6 @@ static void gsb_debug_add_report_page (GtkWidget *assistant,
     if (test->instructions)
     {
 		GtkWidget *expander;
-		GtkWidget *label;
-		gchar *tmp_str;
 
 		tmp_str = g_strconcat ("<b>",_("Details"), "</b>", NULL);
 		expander = gtk_expander_new (tmp_str);
@@ -341,8 +339,6 @@ static gchar *gsb_debug_transfer_test (void)
 					   on affiche son nom */
 					if (!corrupted_account)
 					{
-						gchar *tmp_str;
-
 						tmp_str = g_strdup_printf ("\n<span weight=\"bold\">%s</span>\n",
 												   gsb_data_account_get_name (account_nb));
 						old_str = pText;
@@ -367,8 +363,6 @@ static gchar *gsb_debug_transfer_test (void)
 						   on affiche son nom */
 						if (!corrupted_account)
 						{
-							gchar *tmp_str;
-
 							old_str = pText;
 							tmp_str = g_strdup_printf ("\n<span weight=\"bold\">%s</span>\n",
 													   gsb_data_account_get_name (account_nb));
