@@ -28,18 +28,25 @@
 #endif
 
 #include "include.h"
+
+/*START_INCLUDE*/
 #include "gsb_dirs.h"
 #include "structures.h"
+/*END_INCLUDE*/
 
+/*START_STATIC*/
 static gchar *help_dir;
 static gchar *locale_dir;
 static gchar *pixmaps_dir;
 static gchar *categories_dir;
+static gchar *grisbirc_filename;
 static gchar *themes_dir;
 static gchar *ui_dir;
 static gchar *user_config_dir;
 static gchar *user_data_dir;
 static gchar *user_default_dir;
+static gchar *user_icons_dir = NULL;
+/*END_STATIC*/
 
 /******************************************************************************/
 /* Public functions                                                           */
@@ -56,6 +63,7 @@ void gsb_dirs_init (char* gsb_bin_path)
 	gchar *grisbi_dir;
     gchar *local_ui_dir;
     GDir *local_ui_handle;
+    gchar *filename;
 
     /* Get the grisbi executable directory as it may be useful when running dev instances */
     grisbi_dir = g_path_get_dirname (gsb_bin_path);
@@ -134,15 +142,28 @@ void gsb_dirs_init (char* gsb_bin_path)
 }
 #endif /* G_OS_WIN32 */
 
-    local_ui_handle = g_dir_open (local_ui_dir, 0, NULL);
-    if (NULL != local_ui_handle)
-    {
-        g_free (ui_dir);
-        ui_dir = local_ui_dir;
-		g_dir_close (local_ui_handle);
-    }
-	else
+	/* corrige un bug si un répertoire ui existe dans le compte de l'utilisateur */
+	if (g_strcmp0 (gsb_bin_path, "grisbi") == 0)
+	{
 		g_free (local_ui_dir);
+	}
+	else
+	{
+		local_ui_handle = g_dir_open (local_ui_dir, 0, NULL);
+		if (NULL != local_ui_handle)
+		{
+			g_free (ui_dir);
+			ui_dir = local_ui_dir;
+			g_dir_close (local_ui_handle);
+		}
+		else
+			g_free (local_ui_dir);
+	}
+
+/* init grisbi_rc_filename */
+	filename = g_strconcat (PACKAGE, ".conf", NULL);
+	grisbirc_filename = g_build_filename (user_config_dir, filename, NULL);
+	g_free (filename);
 }
 
 /**
@@ -162,6 +183,9 @@ void gsb_dirs_shutdown (void)
     g_free (user_config_dir);
     g_free (user_data_dir);
     g_free (user_default_dir);
+    g_free (user_icons_dir);
+
+	g_free (grisbirc_filename);
 }
 
 /**
@@ -321,18 +345,11 @@ const gchar *gsb_dirs_get_themes_dir (void)
  *
  * \param
  *
- * \return must be freed
+ * \return
  **/
 const gchar *gsb_dirs_get_grisbirc_filename (void)
 {
-    gchar *filename;
-	gchar *grisbirc_filename;
-
-    filename = g_strconcat (PACKAGE, ".conf", NULL);
-    grisbirc_filename = g_build_filename (user_config_dir, filename, NULL);
-    g_free (filename);
-
-    return grisbirc_filename;
+	return grisbirc_filename;
 }
 
 /**
