@@ -3,7 +3,7 @@
 /*     copyright (c)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2004-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2008-2009 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -37,6 +37,7 @@
 /*START_INCLUDE*/
 #include "gsb_form_transaction.h"
 #include "etats_calculs.h"
+#include "grisbi_app.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency_link.h"
@@ -78,8 +79,10 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
     gint transaction_number = 0;
     gint account_number;
     GSList *tmp_list;
+	GrisbiAppConf *a_conf;
 
     devel_debug (payee_name);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
     if ( !strlen (payee_name))
     return FALSE;
@@ -124,10 +127,8 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
         return TRUE;
 
     /* find the last transaction with that payee */
-    if ( conf.automatic_completion_payee )
-    transaction_number = gsb_form_transactions_look_for_last_party ( payee_number,
-                        0,
-                        account_number );
+    if ( a_conf->automatic_completion_payee )
+    	transaction_number = gsb_form_transactions_look_for_last_party (payee_number, 0, account_number);
 
     /* if no same transaction, go away */
     if ( !transaction_number )
@@ -175,13 +176,13 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
 
 			form_button_recover_split = gsb_form_get_recover_split_button ();
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON ( form_button_recover_split ),
-                        conf.automatic_recover_splits );
+                        a_conf->automatic_recover_splits );
             gtk_widget_show ( form_button_recover_split );
         }
     }
-    else if ( ( element -> element_number == TRANSACTION_FORM_CREDIT && !conf.automatic_erase_credit_debit )
+    else if ( ( element -> element_number == TRANSACTION_FORM_CREDIT && !a_conf->automatic_erase_credit_debit )
          ||
-         ( element -> element_number == TRANSACTION_FORM_DEBIT && !conf.automatic_erase_credit_debit ) )
+         ( element -> element_number == TRANSACTION_FORM_DEBIT && !a_conf->automatic_erase_credit_debit ) )
     {
         gsb_form_fill_element ( element -> element_number,
                         account_number,
@@ -256,14 +257,16 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
  *
  * \return the number of the transaction found, or 0
  * */
-gint gsb_form_transactions_look_for_last_party ( gint no_party,
-                        gint no_new_transaction,
-                        gint account_number )
+gint gsb_form_transactions_look_for_last_party (gint no_party,
+												gint no_new_transaction,
+												gint account_number)
 {
     GSList *list_tmp_transactions;
     gint last_transaction_with_party_in_account = 0;
     gint last_transaction_with_party_not_in_account = 0;
+	GrisbiAppConf *a_conf;
 
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
     list_tmp_transactions = gsb_data_transaction_get_complete_transactions_list ();
 
     while ( list_tmp_transactions )
@@ -291,7 +294,7 @@ gint gsb_form_transactions_look_for_last_party ( gint no_party,
 
     /* if we don't want to complete with a transaction in another account,
      * go away here */
-    if ( conf.limit_completion_to_current_account )
+    if ( a_conf->limit_completion_to_current_account )
 	return 0;
 
     return last_transaction_with_party_not_in_account;
