@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
 /*                      2009-2018 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -36,6 +36,7 @@
 
 /*START_INCLUDE*/
 #include "gsb_form_widget.h"
+#include "grisbi_app.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_combo_box.h"
 #include "gsb_currency.h"
@@ -433,6 +434,9 @@ GtkWidget *gsb_form_widget_create (gint element_number,
 
     if (widget)
     {
+		/* force minimum width */
+		gtk_widget_set_size_request (widget, FORM_COURT_WIDTH, -1);
+
 		/* first, append the widget to the list */
 		struct_element *element;
 
@@ -470,6 +474,8 @@ GtkWidget *gsb_form_widget_create (gint element_number,
 				entry = gtk_combofix_get_entry (GTK_COMBOFIX (widget));
 				if (GTK_IS_ENTRY (entry))
 				{
+					gtk_widget_set_size_request (widget, FORM_LONG_WIDTH, -1);
+
 					g_signal_connect (G_OBJECT (entry),
 									  "focus-in-event",
 									  G_CALLBACK (gsb_form_entry_get_focus),
@@ -527,7 +533,7 @@ GtkWidget *gsb_form_widget_get_widget (gint element_number)
  *
  * \return the name of the element or NULL if problem
  **/
-gchar *gsb_form_widget_get_name (gint element_number)
+const gchar *gsb_form_widget_get_name (gint element_number)
 {
     switch (element_number)
     {
@@ -671,9 +677,13 @@ gint gsb_form_widget_next_element (gint account_number,
 				 &&
 				 row == (form_row_number - 1))
 			{
+				GrisbiAppConf *a_conf;
+
+				a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+
 				/* we are on the bottom right, we finish the edition or
 				 * go to the upper left */
-				if (!conf.form_enter_key)
+				if (!a_conf->form_enter_key)
 				{
 				return_value_number = -2;
 				continue;
@@ -1081,7 +1091,12 @@ gboolean gsb_form_widget_get_valide_amout_entry (const gchar *string)
 
         if (!g_ascii_isdigit (ch))
         {
-            if (g_unichar_isdefined (thousands_sep))
+			if (ch == 0x00A0 || ch == 0x202F/* NON-BREAK SPACE || ESPACE INSÉCABLE ÉTROITE */)
+			{
+				 ptr = g_utf8_next_char (ptr);
+				continue;
+			}
+            else if (g_unichar_isdefined (thousands_sep))
             {
                 if (ch != '.' && ch != ',' && ch != '+' && ch != '-'
                  && ch != '*' && ch != '/' && ch != thousands_sep)
@@ -1274,6 +1289,37 @@ gboolean gsb_form_widget_update_payee_combofix (gint report_number,
     return FALSE;
 }
 
+/**
+ * free the content of the list of structures of the form
+ *
+ * \param
+ *
+ * \return FALSE
+ **/
+gboolean gsb_form_widget_free_list_without_widgets (void)
+{
+	GSList *tmp_list;
+
+    devel_debug (NULL);
+
+    if (!form_list_widgets)
+        return FALSE;
+
+    tmp_list = form_list_widgets;
+    while (tmp_list)
+    {
+        struct_element *element;
+
+        element = tmp_list->data;
+        g_free (element);
+        tmp_list = tmp_list->next;
+    }
+    g_slist_free (form_list_widgets);
+    form_list_widgets = NULL;
+
+	return FALSE;
+}
+
 /**
  *
  *
