@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -35,7 +35,9 @@
 
 /*START_INCLUDE*/
 #include "gsb_fyear.h"
+#include "grisbi_app.h"
 #include "gsb_data_fyear.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 
@@ -242,17 +244,20 @@ gboolean gsb_fyear_update_fyear_list ( void )
  * \return FALSE
  */
 gboolean gsb_fyear_update_fyear_list_new ( GtkTreeModel *model,
-                        GtkTreeModel *model_filter,
-                        gchar *title )
+										  GtkTreeModel *model_filter,
+										  const gchar *title )
 {
-    GSList *list_tmp;
+	GSList *copy_list = NULL;
+	GSList *tmp_list;
     GtkTreeIter iter;
+	GrisbiAppConf *a_conf;
 
     /* if no filter, thats because not created, but don't create here
      * because we can come here without needed of fyear button */
-    if ( !model_filter )
-        return FALSE;
+	if ( !model_filter )
+		return FALSE;
 
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
     gtk_list_store_clear (GTK_LIST_STORE ( model ) );
 
     /* put at the beginning title */
@@ -265,14 +270,26 @@ gboolean gsb_fyear_update_fyear_list_new ( GtkTreeModel *model,
                         -1 );
 
     /* fill the list with the copy of fyears_list */
-    list_tmp = g_slist_sort ( g_slist_copy ( gsb_data_fyear_get_fyears_list ( ) ),
-                        ( GCompareFunc ) gsb_data_fyear_compare_from_struct );
+	tmp_list = gsb_data_fyear_get_fyears_list ();
+    while (tmp_list)
+    {
+	    FyearStruct *fyear;
 
-    while ( list_tmp )
+		fyear = tmp_list ->data;
+		copy_list = g_slist_insert_sorted_with_data (copy_list,
+													 fyear,
+													 (GCompareDataFunc) gsb_data_fyear_compare_from_struct,
+													 GINT_TO_POINTER (a_conf->fyear_combobox_sort_order));
+
+        tmp_list = tmp_list->next;
+    }
+
+	tmp_list = copy_list;
+    while (tmp_list)
     {
         gint fyear_number;
 
-        fyear_number = gsb_data_fyear_get_no_fyear (list_tmp -> data);
+        fyear_number = gsb_data_fyear_get_no_fyear (tmp_list->data);
 
         gtk_list_store_append ( GTK_LIST_STORE ( model ), &iter );
         gtk_list_store_set ( GTK_LIST_STORE ( model ),
@@ -281,8 +298,9 @@ gboolean gsb_fyear_update_fyear_list_new ( GtkTreeModel *model,
                             FYEAR_COL_NUMBER, fyear_number,
                             FYEAR_COL_VIEW, gsb_data_fyear_get_form_show ( fyear_number ),
                             -1 );
-        list_tmp = list_tmp -> next;
+        tmp_list = tmp_list->next;
     }
+	g_slist_free (copy_list);
 
     return FALSE;
 }
