@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*                                                                            */
 /*     Copyright (C)         2011 Grisbi Development Team                     */
-/*             http://www.grisbi.org                                          */
+/*             https://www.grisbi.org/                                         */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -211,6 +211,9 @@ gchar *gsb_locale_get_print_locale_var (void)
     gchar *negative_sign;
     gchar *currency_symbol;
 
+	if (NULL == _locale)
+		return g_strdup("locale not yet configured\n");
+
     /* test local pour les nombres */
 	currency_symbol = g_strdup (_locale->currency_symbol);
 	mon_thousands_sep = g_strdup (_locale->mon_thousands_sep);
@@ -340,7 +343,16 @@ void gsb_locale_init_language (const gchar *new_language)
 	/* set LANGUAGE for gtk3 */
 	g_setenv ("LANGUAGE", language, TRUE);
 	/* set LANG for devise and numbers */
-	tmp_str = g_strconcat (language, ".UTF-8", NULL);
+	if (2 == strlen(language))
+	{
+		/* "it" -> "it_IT.UTF-8" */
+		gchar *LANGUAGE = g_ascii_strup(language, -1);
+		tmp_str = g_strconcat (language, "_", LANGUAGE,".UTF-8", NULL);
+		g_free(LANGUAGE);
+	}
+	else
+		/* language should already be in the form "en_GB" */
+		tmp_str = g_strconcat (language, ".UTF-8", NULL);
 	g_setenv ("LANG", tmp_str, TRUE);
 	g_free (tmp_str);
 	langue = g_strdup (language);
