@@ -4,7 +4,7 @@
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
 /*                      2009-2018 Pierre Biava (grisbi@pierre.biava.name)     */
 /*                      2009 Mickaël Remars (grisbi@remars.com)               */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -210,9 +210,7 @@ static GsbReal gsb_real_double_to_real_add_exponent (gdouble number,
 	if(exp_add >=9)
 		return null_real;
 
-	while (((decimal = modf (number, &tmp_double)) ||
-		real_number.exponent < 0) &&
-		real_number.exponent < 9)
+	while ((modf (number, &tmp_double) || real_number.exponent < 0) && real_number.exponent < 9)
     {
         number = number * 10;
         real_number.exponent++;
@@ -361,6 +359,15 @@ gchar *gsb_real_raw_format_string (GsbReal number,
     cs_end_space = (currency_symbol && !locale->p_cs_precedes && locale->p_sep_by_space) ? " " : "";
     cs_end = (currency_symbol && !locale->p_cs_precedes) ? currency_symbol : "";
 
+	/* on retourne 0.00 avec mon_decimal_point */
+	if (number.mantissa == 0)
+	{
+		if (mon_decimal_point && strlen (mon_decimal_point) == 0)
+        	return g_strdup ("0.00");
+		else
+			return g_strconcat ("0",mon_decimal_point, "00", NULL);
+	}
+
 	denominateur = gsb_real_get_power_10 (number.exponent);
 	units = lldiv (llabs (number.mantissa), denominateur);
 
