@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)	          */
 /*			2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/* 			http://www.grisbi.org				                              */
+/* 			https://www.grisbi.org				                              */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -36,7 +36,7 @@
 #include "gsb_scheduler.h"
 #include "accueil.h"
 #include "bet_finance_ui.h"
-#include "grisbi_win.h"
+#include "grisbi_app.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_fyear.h"
@@ -568,31 +568,33 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
     GDate *date;
     GSList *tmp_list;
     gboolean automatic_transactions_taken = FALSE;
+	GrisbiAppConf *a_conf;
 
     devel_debug (NULL);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
     /* the scheduled transactions to take will be check here,
      * but the scheduled transactions taken will be add to the already appended ones */
 
     scheduled_transactions_to_take = NULL;
 
-    /* get the date today + conf.nb_days_before_scheduled */
+    /* get the date today + a_conf->nb_days_before_scheduled */
 
     /* the date untill we execute the scheduled transactions is :
-     * - either today + conf.nb_days_before_scheduled if warn n days before the scheduled
-     * - either the end of the month in conf.nb_days_before_scheduled days (so current month or next month)
+     * - either today + a_conf->nb_days_before_scheduled if warn n days before the scheduled
+     * - either the end of the month in a_conf->nb_days_before_scheduled days (so current month or next month)
 	 *   or the fixed date
      *   */
     date = gdate_today ();
-    /* now date is in conf.nb_days_before_scheduled, if we want the transactions of the month,
+    /* now date is in a_conf->nb_days_before_scheduled, if we want the transactions of the month,
      * we change date to the end of its month */
-    if (conf.execute_scheduled_of_month)
+    if (a_conf->execute_scheduled_of_month)
     {
 		gint last_day;
 
-		if (conf.scheduler_set_fixed_day
+		if (a_conf->scheduler_set_fixed_day
 			&&
-			g_date_get_day (date) >= conf.scheduler_fixed_day )
+			g_date_get_day (date) >= a_conf->scheduler_fixed_day )
 
 		{
 			g_date_add_months (date, 1);
@@ -604,7 +606,7 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
     }
 	else
 	{
-		g_date_add_days ( date, conf.nb_days_before_scheduled );
+		g_date_add_days ( date, a_conf->nb_days_before_scheduled );
 	}
 
     /* check all the scheduled transactions,
