@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2008-2009 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -53,6 +53,10 @@
 /*END_INCLUDE*/
 
 /*START_STATIC*/
+/* variables de tri primaire et secondaire */
+static gint transactions_list_primary_sorting = 0;
+static gint transactions_list_secondary_sorting = 0;
+
 static gint gsb_transactions_list_sort_by_amount ( gint transaction_number_1,
                         gint transaction_number_2 );
 static gint gsb_transactions_list_sort_by_bank ( gint transaction_number_1,
@@ -104,7 +108,6 @@ static gint gsb_transactions_list_sort_initial_by_secondary_key ( gint transacti
 /*START_EXTERN*/
 /*END_EXTERN*/
 
-
 /**
  * called by a click on the column, used to sort the list
  *
@@ -359,7 +362,8 @@ gint gsb_transactions_list_sort_by_no_sort (  gint transaction_number_1,
 							 transaction_number_2));
 	    break;
 	default :
-	    tmpstr = g_strdup_printf ( _("ask for the sort number %d which doesn't exist... return by date"), element_number );
+	    tmpstr = g_strdup_printf ( _("Ask for the sort number %d which doesn't exist... return by date"),
+	                              element_number );
 	    warning_debug (tmpstr);
 	    g_free(tmpstr);
 	    return ( gsb_transactions_list_sort_by_date ( transaction_number_1,
@@ -512,10 +516,10 @@ gint gsb_transactions_list_sort_by_no ( gint transaction_number_1,
 gint gsb_transactions_list_sort_by_date ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
-    if ( conf.transactions_list_secondary_sorting == 1 )
+    if (transactions_list_secondary_sorting == 1 )
         return gsb_transactions_list_sort_by_date_and_amount (
                         transaction_number_1, transaction_number_2 );
-    else if ( conf.transactions_list_secondary_sorting == 2 )
+    else if (transactions_list_secondary_sorting == 2 )
         return gsb_transactions_list_sort_by_date_and_party (
                         transaction_number_1, transaction_number_2 );
     else
@@ -540,17 +544,17 @@ gint gsb_transactions_list_sort_by_value_date ( gint transaction_number_1,
     const GDate *value_date_1 = NULL;
     const GDate *value_date_2 = NULL;
 
-	if (conf.transactions_list_primary_sorting == 2)
+	if (transactions_list_primary_sorting == 2)
 		return gsb_transactions_list_sort_by_date (transaction_number_1, transaction_number_2);
 
    /* need to work a little more here because value date is not obligatory filled,
      * if we compare 2 transactions and 1 has no value date, set the value date before */
     value_date_1 = gsb_data_transaction_get_value_date ( transaction_number_1 );
-    if ( !value_date_1 && !conf.transactions_list_primary_sorting )
+    if ( !value_date_1 && !transactions_list_primary_sorting )
         value_date_1 = gsb_data_transaction_get_date ( transaction_number_1 );
 
     value_date_2 = gsb_data_transaction_get_value_date ( transaction_number_2 );
-    if ( !value_date_2 && !conf.transactions_list_primary_sorting )
+    if ( !value_date_2 && !transactions_list_primary_sorting )
         value_date_2 = gsb_data_transaction_get_date ( transaction_number_2 );
 
     if ( value_date_1 )
@@ -926,8 +930,8 @@ gint gsb_transactions_list_sort_by_category ( gint transaction_number_1,
      * and after, we sort by str
      * */
 
-    temp_1 = gsb_transactions_get_category_real_name ( transaction_number_1);
-    temp_2 = gsb_transactions_get_category_real_name ( transaction_number_2);
+    temp_1 = gsb_data_transaction_get_category_real_name ( transaction_number_1);
+    temp_2 = gsb_data_transaction_get_category_real_name ( transaction_number_2);
 
     /* g_utf8_collate is said not very fast, must try with big big account to check
      * if it's enough, for me it's ok (cedric), eventually, change with gsb_strcasecmp */
@@ -1178,20 +1182,50 @@ gint gsb_transactions_list_sort_initial (CustomRecord **a,
 gint gsb_transactions_list_sort_initial_by_secondary_key ( gint transaction_number_1,
                         gint transaction_number_2 )
 {
-    if ( conf.transactions_list_secondary_sorting == 1 )
+    if (transactions_list_secondary_sorting == 1 )
         return gsb_transactions_list_sort_by_amount (
                         transaction_number_1, transaction_number_2 );
-    else if ( conf.transactions_list_secondary_sorting == 2 )
+    else if (transactions_list_secondary_sorting == 2 )
         return gsb_transactions_list_sort_by_party (
                         transaction_number_1, transaction_number_2 );
-    else if ( conf.transactions_list_secondary_sorting == 3 )
+    else if (transactions_list_secondary_sorting == 3 )
         return gsb_transactions_list_sort_by_date_and_no (
                         transaction_number_1, transaction_number_2 );
     else
         return transaction_number_1 - transaction_number_2;
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void gsb_transactions_list_set_primary_sort (gint primary_sort)
+{
+	transactions_list_primary_sorting = primary_sort;
+}
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void gsb_transactions_list_set_secondary_sort (gint secondary_sort)
+{
+	transactions_list_secondary_sorting = secondary_sort;
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
