@@ -3,7 +3,7 @@
 /*     Copyright (C)    2001-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2009-2019 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -33,7 +33,7 @@
 
 /*START_INCLUDE*/
 #include "gtk_combofix.h"
-#include "grisbi_win.h"
+#include "grisbi_app.h"
 #include "gsb_data_account.h"
 #include "gsb_data_budget.h"
 #include "gsb_data_category.h"
@@ -119,7 +119,7 @@ enum CombofixKeyDirection
  *
  * \return FALSE
  **/
-static gboolean gtk_combofix_completion_match_selected (GtkEntryCompletion *widget,
+static gboolean gtk_combofix_completion_match_selected (GtkEntryCompletion *entry,
 														GtkTreeModel *model,
 														GtkTreeIter *iter,
 														GtkComboFix *combofix)
@@ -565,6 +565,7 @@ static gboolean gtk_combofix_fill_store (GtkComboFix *combofix,
 	GtkEntryCompletion *completion;
 	GtkTreeModel *completion_store;
     GtkTreeIter iter_parent;
+	gchar *free_str1;
     gchar *last_parent = NULL;
     GtkComboFixPrivate *priv;
 
@@ -586,6 +587,7 @@ static gboolean gtk_combofix_fill_store (GtkComboFix *combofix,
 	completion = gtk_entry_get_completion (GTK_ENTRY (priv->entry));
 	completion_store = gtk_entry_completion_get_model (completion);
 
+	free_str1 = g_utf8_casefold (_("Report"), -1);
     tmp_list = list;
 
     while (tmp_list)
@@ -618,11 +620,15 @@ static gboolean gtk_combofix_fill_store (GtkComboFix *combofix,
 				/* append a row in the completion ignore reports for payees */
 				if (priv->type == METATREE_PAYEE)
 				{
-					if (g_utf8_collate (g_utf8_casefold (_("Report"), -1), g_utf8_casefold (string, -1)))
+					gchar *free_str2;
+
+					free_str2 = g_utf8_casefold (string, -1);
+					if (g_utf8_collate (free_str1, free_str2))
 					{
 						gtk_list_store_append (GTK_LIST_STORE (completion_store), &new_iter);
 						gtk_list_store_set (GTK_LIST_STORE (completion_store), &new_iter, 0, string, -1);
 					}
+					g_free (free_str2);
 				}
 				else
 				{
@@ -663,6 +669,7 @@ static gboolean gtk_combofix_fill_store (GtkComboFix *combofix,
 
         tmp_list = tmp_list->next;
     }
+	g_free (free_str1);
 
     priv->visible_items += g_slist_length (list);
 
@@ -1265,7 +1272,7 @@ static gboolean gtk_combofix_move_selection (GtkComboFix *combofix,
 }
 
 /**
- * called for a key_press_event on the entry of the combofix
+ * called for a key-press-event on the entry of the combofix
  *
  * \param entry
  * \param ev
@@ -1277,9 +1284,11 @@ static gboolean gtk_combofix_key_press_event (GtkWidget *entry,
 											  GdkEventKey *ev,
 											  GtkComboFix *combofix)
 {
+	GrisbiAppConf *a_conf;
     GtkComboFixPrivate *priv;
 
     priv = gtk_combofix_get_instance_private (combofix);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
     switch (ev->keyval)
     {
@@ -1300,7 +1309,7 @@ static gboolean gtk_combofix_key_press_event (GtkWidget *entry,
 				}
 			}
 			else if ((gint) strlen (gtk_entry_get_text (GTK_ENTRY (priv->entry))) >=
-					 conf.completion_minimum_key_length)
+					 a_conf->completion_minimum_key_length)
 			{
 				gtk_combofix_completion_choose_first_item (entry);
 			}
@@ -1627,9 +1636,11 @@ static void gtk_combofix_create_entry (GtkComboFix *combofix)
 {
 	GtkEntryCompletion *completion;
 	GtkListStore *completion_store;
+	GrisbiAppConf *a_conf;
     GtkComboFixPrivate *priv;
 
     priv = gtk_combofix_get_instance_private (combofix);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
 	/* create entry */
     priv->entry = gtk_entry_new ();
@@ -1642,7 +1653,7 @@ static void gtk_combofix_create_entry (GtkComboFix *combofix)
 											 (GtkEntryCompletionMatchFunc) gtk_combofix_completion_match_func,
 											 NULL,
 											 NULL);
-	gtk_entry_completion_set_minimum_key_length (completion, conf.completion_minimum_key_length);
+	gtk_entry_completion_set_minimum_key_length (completion, a_conf->completion_minimum_key_length);
 	gtk_entry_completion_set_popup_single_match (completion, TRUE);
 	gtk_entry_completion_set_text_column (completion, 0);
 
@@ -2222,7 +2233,10 @@ gboolean gtk_combofix_set_list (GtkComboFix *combofix,
     g_return_val_if_fail (list, FALSE);
 
     priv = gtk_combofix_get_instance_private (combofix);
-    gtk_tree_store_clear (priv->store);
+	if (!priv->store || !GTK_IS_TREE_STORE (priv->store))
+		return  FALSE;
+	else
+	    gtk_tree_store_clear (priv->store);
 
 	completion = gtk_entry_get_completion (GTK_ENTRY (priv->entry));
 	completion_store = gtk_entry_completion_get_model (completion);
@@ -2536,8 +2550,6 @@ void gtk_combofix_remove_report (GtkComboFix *combofix,
 
     while (valid)
     {
-        gchar *tmp_str;
-
         gtk_tree_model_get (completion_model, &iter, 0, &tmp_str, -1);
 
         if (etat.combofix_case_sensitive && !strcmp (tmp_str2, tmp_str))
