@@ -2,8 +2,8 @@
 /*                                                                            */
 /*     copyright (c)    2000-2003 Cédric Auger (cedric@grisbi.org)            */
 /*          2008 Benjamin Drieu (bdrieu@april.org)                            */
-/*          2008-2010 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          2008-2020 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -113,7 +113,7 @@ void a_propos ( GtkWidget *bouton, gint data )
 {
     GtkWidget *about;
     GdkPixbuf *logo;
-    gchar *chemin_logo ;
+	gboolean logo_is_local = FALSE;
 
 #define CSUFFIX "\n"
 
@@ -122,7 +122,7 @@ _("Programming"),
 "Benjamin Drieu <bdrieu@april.org>",
 "Cedric Auger <cedric@grisbi.org>",
 "Francois Terrot <grisbi@terrot.net>",
-"Pierre Biava <pierre.biava@nerim.net>",
+"Pierre Biava <pierre@pierre.biava.name>",
 "Mickaël Remars <grisbi@remars.com>",
 "William Ollivier <guneeyoufix@gmail.com>",
 "Rémi Cardona <remi@gentoo.org>",
@@ -201,48 +201,30 @@ NULL};
     extra = extra_support ( );
     version_to_string = get_gtk_run_version ( );
 
-    if ( IS_DEVELOPMENT_VERSION == 1 )
-    {
-        gchar *compiled_time;
-
-        compiled_time = gsb_date_get_compiled_time ( );
-        comments = g_strconcat ( _("Personal finance manager for everyone\n"),
-                        extra,
-                        "Version de GTK : ",
-                        version_to_string,
-                        "\n",
-                        _("This instance of Grisbi was compiled on\n"),
-                        compiled_time,
-                        " ",
-                        _("at"),
-                        " ",
-                        __TIME__,
-                        NULL );
-
-        g_free ( compiled_time );
-    }
-    else
-        comments = g_strconcat ( _("Personal finance manager for everyone\n"),
-                        extra,
-                        "Version de GTK : ",
-                        version_to_string,
-                        NULL );
+	comments = g_strconcat ( _("Personal finance manager for everyone\n"),
+					extra,
+					_("GTK+ version: "),
+					version_to_string,
+#ifdef DEBUG
+					"\n",
+					_("Grisbi git hash: "),
+					GIT_HASH,
+#endif
+					NULL );
 
     /* Logo */
     logo = gsb_select_icon_get_logo_pixbuf ( );
     if (logo == NULL )
     {
-        chemin_logo = my_strdup ( LOGO_PATH );
-        logo =  gdk_pixbuf_new_from_file ( chemin_logo, NULL );
-
-        g_free ( chemin_logo );
+        logo =  gsb_select_icon_get_default_logo_pixbuf ();
+		logo_is_local = TRUE;
     }
 
     about = gtk_about_dialog_new ( );
     gtk_about_dialog_set_program_name ( GTK_ABOUT_DIALOG (about), "Grisbi" );
     gtk_about_dialog_set_logo ( GTK_ABOUT_DIALOG (about), logo );
     gtk_about_dialog_set_comments ( GTK_ABOUT_DIALOG (about), comments );
-    gtk_about_dialog_set_website ( GTK_ABOUT_DIALOG (about), "http://www.grisbi.org/");
+    gtk_about_dialog_set_website ( GTK_ABOUT_DIALOG (about), "https://www.grisbi.org/");
     gtk_about_dialog_set_license ( GTK_ABOUT_DIALOG (about), license );
     gtk_about_dialog_set_wrap_license ( GTK_ABOUT_DIALOG (about), TRUE );
     gtk_about_dialog_set_version ( GTK_ABOUT_DIALOG (about), VERSION );
@@ -268,8 +250,8 @@ NULL};
 
     gtk_widget_destroy (about);
 
-    if (logo)
-    g_object_unref (logo);
+	if (logo_is_local)
+		g_object_unref (logo);
 
     return;
 }
