@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2003 Cédric Auger  (cedric@grisbi.org)           */
 /*          2004-2006 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2008-2018 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -52,6 +52,9 @@ extern GSList *liste_comptes_importes_error;
 /*START_STATIC*/
 /*END_STATIC*/
 
+/* liste des lignes à conserver action = 2 */
+static GSList *list_lines_to_keep = NULL;
+
 /** Array of pointers to fields.  */
 static gint *csv_fields_config = NULL;
 
@@ -267,6 +270,7 @@ static GArray *csv_import_button_rule_traite_spec_line (SpecConfData *spec_conf_
 {
     GSList *list;
 	gint action;
+	gint removed_line = 0;
 
 	devel_debug (NULL);
 	if (!csv_fields_config || !lines_tab)
@@ -287,8 +291,32 @@ static GArray *csv_import_button_rule_traite_spec_line (SpecConfData *spec_conf_
 		{
 			if (action == 0) 		/* suppression de la ligne */
 			{
-				g_array_remove_index (lines_tab, index);
-				index--;
+				GSList *link;
+
+				if (list_lines_to_keep)
+				{
+					link = g_slist_find (list_lines_to_keep, GINT_TO_POINTER (index+removed_line));
+					if (link)
+					{
+						list_lines_to_keep = g_slist_delete_link (list_lines_to_keep, link);
+						if (!list_lines_to_keep)
+						{
+							list_lines_to_keep = NULL;
+						}
+					}
+					else
+					{
+						g_array_remove_index (lines_tab, index);
+						index--;
+						removed_line++;
+					}
+				}
+				else
+				{
+					g_array_remove_index (lines_tab, index);
+					index--;
+					removed_line++;
+				}
 			}
 			else if (action == 1)	/* inversion du montant */
 			{
@@ -317,6 +345,12 @@ static GArray *csv_import_button_rule_traite_spec_line (SpecConfData *spec_conf_
 				str_montant = utils_real_get_string (montant);
 				list = g_slist_delete_link (list, link);
 				list = g_slist_insert (list, g_strdup (str_montant), spec_conf_data->csv_spec_conf_action_data);
+				if (!list)
+					notice_debug ("Warning: Invalid data");
+			}
+			else if (action == 2)
+			{
+				list_lines_to_keep = g_slist_append (list_lines_to_keep, GINT_TO_POINTER (index));
 			}
 		}
 
@@ -418,7 +452,7 @@ static void csv_import_button_rule_clicked (GtkButton *button,
  * \return			Parsed list or NULL upon failure (last line).
  **/
 static GSList *csv_get_next_line (gchar **contents,
-								  gchar *separator)
+								  const gchar *separator)
 {
     GSList *list;
 
@@ -505,7 +539,7 @@ static gint csv_import_count_columns (GArray *lines_tab,
  **/
 static gint csv_skip_lines (gchar **contents,
 							gint num_lines,
-							gchar *separator)
+							const gchar *separator)
 {
     GSList *list;
     int i;
@@ -533,7 +567,7 @@ static gint csv_skip_lines (gchar **contents,
  *
  * \return			TRUE if substring is contained into original.
  **/
-static gboolean safe_contains (gchar *original,
+static gboolean safe_contains (const gchar *original,
 							   gchar *substring)
 {
 	gchar *tmp_original;
@@ -573,6 +607,8 @@ static gint *csv_import_guess_fields_config (GArray *lines_tab,
 	gint i;
     GSList *list;
 	gboolean date_validated = 0;
+	gboolean is_credit = FALSE;
+	gboolean is_debit = FALSE;
 
     default_config = (gint *) g_malloc0 ((size + 1) * sizeof (int));
 
@@ -647,6 +683,12 @@ static gint *csv_import_guess_fields_config (GArray *lines_tab,
 	{
 		string = list->data;
 
+		/* sert a tester unicité du debit et du credit */
+		if (default_config [i] == 12)
+			is_credit = TRUE;
+		else if (default_config [i] == 13)
+			is_debit = TRUE;
+
 		if (strlen (string))
 		{
 			if (csv_import_validate_date (string) && !date_validated && !default_config [i])
@@ -660,9 +702,9 @@ static gint *csv_import_guess_fields_config (GArray *lines_tab,
 			{
 				if (g_strrstr (string, "-")) /* This is negative */
 				{
-					if (!default_config [i])
+					if (!default_config [i] && !is_credit && !is_debit)
 					{
-						default_config [i] = 11; /* Negative debit */
+						default_config [i] = 11; /* Neutral amount */
 					}
 					else if (default_config [i] == 12)
 					{
@@ -671,9 +713,9 @@ static gint *csv_import_guess_fields_config (GArray *lines_tab,
 				}
 				else
 				{
-					if (!default_config [i])
+					if (!default_config [i] && !is_credit && !is_debit)
 					{
-						default_config [i] = 12; /* Negative debit */
+						default_config [i] = 11; /* Neutral amount */
 					}
 					else if (default_config [i] == 14)
 					{
@@ -806,11 +848,11 @@ static void csv_import_update_validity_check (GtkWidget *assistant)
     {
         if (label)
         {
-            label = g_strconcat (label, ", ", _("transaction amount"), NULL);
+            label = g_strconcat (label, ", ", _("Transaction amount"), NULL);
         }
         else
         {
-            label = my_strdup (_("transaction amount"));
+            label = my_strdup (_("Transaction amount"));
         }
     }
 
@@ -1091,7 +1133,7 @@ static GtkTreeModel *csv_import_create_model (GtkTreeView *tree_preview,
  * \return			FALSE on failure, number of columns otherwise.
  **/
 static gint csv_import_try_separator (gchar *contents,
-									  gchar *separator)
+									  const gchar *separator)
 {
     GSList *list;
     int cols, i = 0;
@@ -1140,7 +1182,7 @@ static gint csv_import_try_separator (gchar *contents,
  **/
 static gchar *csv_import_guess_separator (gchar *contents)
 {
-    gchar *separators[5] = { ",", ";", "	", " ", NULL }, *cmax = NULL;
+    const gchar *separators[5] = { ";", ",", "	", " ", NULL }, *cmax = NULL;
     gint i, max = 0;
 
     for (i = 0 ; separators[i] ; i++)
@@ -1215,6 +1257,7 @@ static gboolean csv_import_update_preview (GtkWidget *assistant)
 
         if (!list)
         {
+			csv_import_update_validity_check (assistant);
             return FALSE;
         }
 
@@ -1268,7 +1311,7 @@ static gboolean csv_import_change_separator (GtkEntry *entry,
 
 	if (strlen (separator) > 0)
     {
-		gchar *contents;
+		gchar *contents = NULL;
 		GArray *lines_tab;
 
         g_object_set_data (G_OBJECT(assistant), "separator", separator);
@@ -1276,9 +1319,13 @@ static gboolean csv_import_change_separator (GtkEntry *entry,
 			g_free (etat.csv_separator);
 		etat.csv_separator = separator;
 		contents = g_object_get_data (G_OBJECT(assistant), "contents");
+		if (!contents || strlen (contents) == 0)
+			return FALSE;
+
 		lines_tab = g_object_get_data (G_OBJECT(assistant), "lines_tab");
 		if (lines_tab)
 			csv_import_free_lines_tab (lines_tab);
+
 		lines_tab = csv_import_init_lines_tab (&contents, etat.csv_separator);
 		g_object_set_data (G_OBJECT(assistant), "lines-tab", lines_tab);
 		first_line_with_cols = 0;
@@ -1288,7 +1335,7 @@ static gboolean csv_import_change_separator (GtkEntry *entry,
     {
 		if (etat.csv_separator)
 			g_free (etat.csv_separator);
-        etat.csv_separator = "";
+        etat.csv_separator = (gchar*)"";
         g_object_set_data (G_OBJECT(assistant), "separator", NULL);
     }
 
@@ -1328,7 +1375,7 @@ gboolean csv_import_file_by_rule (gint rule,
 
 	devel_debug (imported->name);
 	contents = gsb_file_test_and_load_csv_file (imported);
-	if (!contents)
+		if (!contents || strlen (contents) == 0)
 		return FALSE;
 
 	compte = g_malloc0 (sizeof (struct ImportAccount));
