@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2004-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2009-2011 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -121,9 +121,7 @@ GtkWidget *budgetary_lines_create_list ( void )
     GtkCellRenderer *cell;
     GtkTreeDragDestIface * dst_iface;
     GtkTreeDragSourceIface * src_iface;
-    static GtkTargetEntry row_targets[] = {
-	{ "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }
-    };
+    static GtkTargetEntry row_targets[] = {{(gchar*)"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0}};
 
 	window = GTK_WIDGET (grisbi_app_get_active_window (NULL));
 
@@ -131,7 +129,7 @@ GtkWidget *budgetary_lines_create_list ( void )
     budgetary_line_tree = gtk_tree_view_new();
 
 	/* set the color of selected row */
-	gtk_widget_set_name (budgetary_line_tree, "tree_view");
+	gtk_widget_set_name (budgetary_line_tree, "colorized_tree_view");
 
     budgetary_line_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS,
 						     META_TREE_COLUMN_TYPES );
@@ -284,7 +282,10 @@ void budgetary_lines_fill_list ( void )
     devel_debug (NULL);
 
     /** First, remove previous tree */
-    gtk_tree_store_clear ( GTK_TREE_STORE (budgetary_line_tree_model));
+	if (!budgetary_line_tree_model || !GTK_IS_TREE_STORE (budgetary_line_tree_model))
+		return;
+	else
+	    gtk_tree_store_clear (GTK_TREE_STORE (budgetary_line_tree_model));
 
     /* Compute budget balances. */
     gsb_data_budget_update_counters ();
@@ -564,7 +565,7 @@ void budgetary_lines_importer_list ( void )
 	    case 2 :
             /* we want to replace the list */
             if ( !last_transaction_number )
-                gsb_data_budget_init_variables ();
+                gsb_data_budget_init_variables (TRUE);
 
 		/* FALLTHRU */
         case 1 :
@@ -1062,7 +1063,9 @@ gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
         GtkTreeIter iter;
         GtkTreePath *path = NULL;
         enum MetaTreeRowType type_division;
+		GrisbiAppConf *a_conf;
 
+		a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
         type_division = metatree_get_row_type_from_tree_view ( tree_view );
         if ( type_division == META_TREE_TRANSACTION )
             return FALSE;
@@ -1073,7 +1076,7 @@ gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
 		else
 			return FALSE;
 
-        if ( conf.metatree_action_2button_press == 0 || type_division == META_TREE_DIV )
+        if ( a_conf->metatree_action_2button_press == 0 || type_division == META_TREE_DIV )
         {
             if ( gtk_tree_view_row_expanded ( GTK_TREE_VIEW ( tree_view ), path ) )
                 gtk_tree_view_collapse_row ( GTK_TREE_VIEW ( tree_view ), path );
@@ -1083,7 +1086,7 @@ gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
             gtk_tree_path_free ( path );
             return FALSE;
         }
-        else if ( conf.metatree_action_2button_press == 1 )
+        else if ( a_conf->metatree_action_2button_press == 1 )
         {
             edit_budgetary_line ( GTK_TREE_VIEW ( tree_view ) );
 
