@@ -79,21 +79,20 @@ int main (int argc, char **argv)
     GSList *goffice_plugins_dirs = NULL;
 #endif
 	/* On force l'utilisation de X11 en attendant que grisbi fonctionne correctement sous wayland */
-/*#ifdef GDK_WINDOWING_WAYLAND
+#ifdef GDK_WINDOWING_WAYLAND
 	#ifdef GDK_WINDOWING_X11
 		gdk_set_allowed_backends ("x11");
 	#else
 		return (1);
 	#endif
 #endif
-*/
 
 #ifdef EARLY_DEBUG
 	debug_start_log_file ();
 #endif
 
 #ifdef __APPLE__
-    goffice_plugins_dirs = grisbi_osx_init(&argc, &argv);
+     goffice_plugins_dirs = grisbi_osx_init(&argc, argv);
 #endif
 
 	/* On commence par initialiser les répertoires */
@@ -110,6 +109,7 @@ int main (int argc, char **argv)
     libgoffice_init ();
     /* Initialize plugins manager */
     go_plugins_init (NULL, NULL, NULL, goffice_plugins_dirs, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
+    /* Note: go_plugins_init will g_slist_free(goffice_plugins_dirs) ! */
 #endif /* HAVE_GOFFICE */
 
     app = g_object_new (GRISBI_APP_TYPE,
@@ -127,9 +127,9 @@ int main (int argc, char **argv)
 #ifdef HAVE_GOFFICE
     /* liberation libgoffice */
     libgoffice_shutdown ();
-    g_slist_free(goffice_plugins_dirs); //, g_free);
 #endif /* HAVE_GOFFICE */
 
+
     return status;
 }
 
