@@ -357,6 +357,9 @@ GtkWidget *gsb_gui_navigation_create_navigation_pane ( void )
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( navigation_tree_view ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
 
+	/* disable searching searching */
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (navigation_tree_view), -1);
+
     /* crée les pages dans le panneau de gauche */
     tmp_queue = gsb_gui_navigation_get_pages_list ( );
 
@@ -1271,9 +1274,6 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 			title = g_strdup(_("Scheduled transactions"));
 
 			/* what to be done if switch to that page */
-			/* update the list (can do that because short list, so very fast) */
-			gsb_scheduler_list_update_tree_view (gsb_scheduler_list_get_tree_view ());
-
 			/* set the form */
 			grisbi_win_set_form_expander_visible (TRUE, FALSE );
 			gsb_form_scheduler_clean ();
@@ -1288,6 +1288,10 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 
 			/* show menu InitwidthCol */
 			gsb_menu_gui_sensitive_win_menu_item ( "reset-width-col", TRUE );
+
+			/* set last_selected_scheduler option */
+			gsb_scheduler_list_update_tree_view (gsb_scheduler_list_get_tree_view ());
+
 			break;
 
 		case GSB_PAYEES_PAGE:
@@ -1371,8 +1375,8 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
         grisbi_win_headings_update_title ( title );
         g_free ( title );
     }
-    if (clear_suffix)
-        grisbi_win_headings_update_suffix ( "" );
+	if (clear_suffix)
+		grisbi_win_headings_update_suffix ( "" );
 
     return FALSE;
 }
