@@ -51,6 +51,7 @@ gboolean 		gsb_gui_navigation_check_scroll 				(GtkWidget *tree_view,
 																 gpointer user_data);
 void 			gsb_gui_navigation_create_account_list 			(GtkTreeModel *model);
 GtkWidget *		gsb_gui_navigation_create_navigation_pane 		(void);
+void			gsb_gui_navigation_create_report_list			(GtkTreeModel *model);
 gboolean 		gsb_gui_navigation_drag_data_received 			(GtkTreeDragDest *drag_dest,
 																 GtkTreePath *dest_path,
 																 GtkSelectionData *selection_data);
@@ -77,6 +78,8 @@ gboolean 		gsb_gui_navigation_set_selection 				(gint page,
 void 			gsb_gui_navigation_update_account 				(gint account_number);
 void 			gsb_gui_navigation_update_account_label 		(gint account_number);
 void 			gsb_gui_navigation_update_home_page 			(void);
+void 			gsb_gui_navigation_update_home_page_from_theme	(void);
+void			gsb_gui_navigation_update_localisation			(gint type_maj);
 void 			gsb_gui_navigation_update_report 				(gint report_number) ;
 void 			gsb_gui_navigation_update_statement_label 		(gint account_number);
 gboolean 		gsb_gui_navigation_row_drop_possible 			(GtkTreeDragDest *drag_dest,
@@ -85,6 +88,7 @@ gboolean 		gsb_gui_navigation_row_drop_possible 			(GtkTreeDragDest *drag_dest,
 gulong 			gsb_gui_navigation_tree_view_selection_changed 	(void);
 
 void 			gsb_gui_navigation_select_reports_page			(void);
+
 /* END_DECLARATION */
 
 #endif
