@@ -6,7 +6,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
 /*          2008-2018 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          http://www.grisbi.org                                                */
+/*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -39,7 +39,6 @@
 /*START_INCLUDE*/
 #include "prefs_page_accueil.h"
 #include "grisbi_app.h"
-#include "grisbi_settings.h"
 #include "gsb_automem.h"
 #include "gsb_locale.h"
 #include "gsb_data_partial_balance.h"
@@ -62,7 +61,6 @@ struct _PrefsPageAccueilPrivate
 
 	GtkWidget *			box_lang_fr;
     GtkWidget *			checkbutton_balances_with_scheduled;
-	GtkWidget *			eventbox_balances_with_scheduled;
     GtkWidget *			hbox_paddingbox_lang_fr;
     GtkWidget *         hbox_paddingbox_partial_balance;
 	GtkWidget *			vbox_loading_partial_balance;
@@ -71,7 +69,6 @@ struct _PrefsPageAccueilPrivate
 	GtkWidget *			button_partial_balance_remove;
     GtkWidget *         treeview_partial_balance;
     GtkWidget *			checkbutton_partial_balance;
-	GtkWidget *			eventbox_partial_balance;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageAccueil, prefs_page_accueil, GTK_TYPE_BOX)
@@ -87,17 +84,11 @@ G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageAccueil, prefs_page_accueil, GTK_TYPE_BOX)
  * \return  FALSE
  * */
 static gboolean prefs_page_accueil_checkbutton_balances_with_scheduled_toggle (GtkToggleButton *button,
-																			   gpointer null)
+																			   GrisbiAppConf *a_conf)
 {
     GSList *list_tmp;
-	GSettings *settings;
 
-	settings = grisbi_settings_get_settings (SETTINGS_SCHEDULED);
-    g_settings_set_boolean (G_SETTINGS (settings),
-							"balances-with-scheduled",
-							conf.balances_with_scheduled);
-
-    list_tmp = gsb_data_account_get_list_accounts ();
+	list_tmp = gsb_data_account_get_list_accounts ();
     while (list_tmp)
     {
         gint account_number;
@@ -114,7 +105,7 @@ static gboolean prefs_page_accueil_checkbutton_balances_with_scheduled_toggle (G
 }
 
 /**
- * callback function for conf.group_partial_balance_under_account variable
+ * callback function for a_conf->group_partial_balance_under_account variable
  *
  * \param button        object clicked
  * \param user_data
@@ -122,14 +113,8 @@ static gboolean prefs_page_accueil_checkbutton_balances_with_scheduled_toggle (G
  * \return              FALSE
  * */
 static gboolean prefs_page_accueil_checkbutton_partial_balance_toggle (GtkToggleButton *button,
-																	   gpointer null)
+																	   GrisbiAppConf *a_conf)
 {
-	GSettings *settings;
-
-	settings = grisbi_settings_get_settings (SETTINGS_DISPLAY);
-    g_settings_set_boolean (G_SETTINGS (settings),
-							"group-partial-balance-under-accounts",
-							conf.group_partial_balance_under_accounts);
     gsb_gui_navigation_update_home_page ();
 	utils_prefs_gsb_file_set_modified ();
 
@@ -137,7 +122,7 @@ static gboolean prefs_page_accueil_checkbutton_partial_balance_toggle (GtkToggle
 }
 
 /**
- * callback function for conf.pluriel_final variable
+ * callback function for a_conf->pluriel_final variable
  *
  * \param button        object clicked
  * \param user_data
@@ -145,14 +130,8 @@ static gboolean prefs_page_accueil_checkbutton_partial_balance_toggle (GtkToggle
  * \return              FALSE
  * */
 static gboolean prefs_page_accueil_checkbutton_pluriel_final_toggle (GtkToggleButton *button,
-																	 gpointer null)
+																	 GrisbiAppConf *a_conf)
 {
-	GSettings *settings;
-
-	settings = grisbi_settings_get_settings (SETTINGS_GENERAL);
-    g_settings_set_boolean (G_SETTINGS (settings),
-							"pluriel-final",
-							conf.pluriel_final);
     gsb_gui_navigation_update_home_page ();
 	utils_prefs_gsb_file_set_modified ();
 
@@ -197,12 +176,15 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 {
 	GtkWidget *head_page;
 	const gchar *langue;
+	gchar *tmp_str;
 	gboolean is_loading;
+	GrisbiAppConf *a_conf;
 	PrefsPageAccueilPrivate *priv;
 
 	devel_debug (NULL);
 
 	priv = prefs_page_accueil_get_instance_private (page);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 	is_loading = grisbi_win_file_is_loading ();
 
 	/* On récupère le nom de la page */
@@ -212,27 +194,29 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 
     /* set the box for french langage*/
 	langue = gsb_locale_get_language ();
-    if (langue && g_strstr_len ((g_ascii_strup (langue, -1)), -1, "FR"))
+	tmp_str = g_ascii_strup (langue, -1);
+    if (langue && g_strstr_len (tmp_str, -1, "FR"))
     {
 		GtkWidget *vbox_button;
 
-		vbox_button = gsb_automem_radiobutton_blue_new ("Soldes finals",
+		vbox_button = gsb_automem_radiobutton_gsettings_new ("Soldes finals",
 														"Soldes finaux",
-														&conf.pluriel_final,
+														&a_conf->pluriel_final,
 														G_CALLBACK (prefs_page_accueil_checkbutton_pluriel_final_toggle),
-														NULL);
+														a_conf);
 		gtk_box_pack_start (GTK_BOX (priv->box_lang_fr), vbox_button, FALSE, FALSE, 0);
 		gtk_box_pack_start (GTK_BOX (priv->vbox_accueil), priv->hbox_paddingbox_lang_fr, FALSE, FALSE, 0);
 		gtk_box_reorder_child (GTK_BOX (priv->vbox_accueil), priv->hbox_paddingbox_lang_fr, 1);
     }
+	g_free (tmp_str);
 
-	/* set conf.balances_with_scheduled */
+	/* set a_conf->balances_with_scheduled */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_balances_with_scheduled),
-								  conf.balances_with_scheduled);
+								  a_conf->balances_with_scheduled);
 
-	/* set conf.group_partial_balance_under_accounts */
+	/* set a_conf->group_partial_balance_under_accounts */
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_partial_balance),
-								  conf.group_partial_balance_under_accounts);
+								  a_conf->group_partial_balance_under_accounts);
 
 	/* set data for buttons */
 	g_object_set_data (G_OBJECT (priv->vbox_accueil), "add_button", priv->button_partial_balance_add);
@@ -240,30 +224,29 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
     g_object_set_data (G_OBJECT (priv->vbox_accueil), "remove_button", priv->button_partial_balance_remove);
 
 	/* Connect signal checkbutton_balances_with_scheduled */
-    g_signal_connect (priv->eventbox_balances_with_scheduled,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_balances_with_scheduled);
-
     g_signal_connect (priv->checkbutton_balances_with_scheduled,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.balances_with_scheduled);
+					  &a_conf->balances_with_scheduled);
 
 	/* Connect signal checkbutton_partial_balance */
-    g_signal_connect (priv->eventbox_partial_balance,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_partial_balance);
-
     g_signal_connect (priv->checkbutton_partial_balance,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.group_partial_balance_under_accounts);
+					  &a_conf->group_partial_balance_under_accounts);
+
+	/* set gsettings */
+	g_signal_connect_after (priv->checkbutton_balances_with_scheduled,
+							"toggled",
+							G_CALLBACK (prefs_page_accueil_checkbutton_balances_with_scheduled_toggle),
+							a_conf);
+    g_signal_connect_after (priv->checkbutton_partial_balance,
+							"toggled",
+							G_CALLBACK (prefs_page_accueil_checkbutton_partial_balance_toggle),
+							a_conf);
 
 	if (is_loading)
 	{
-		GtkWidget *window;
 		GtkWidget *treeview;
 	    GtkListStore *list_store;
 		GtkTreeViewColumn *column;
@@ -271,9 +254,7 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 		GtkTreeSelection *selection;
 		GtkTreeDragDestIface * dst_iface;
 		GtkTreeDragSourceIface * src_iface;
-		static GtkTargetEntry row_targets[] = {{"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0}};
-
-		window = GTK_WIDGET (grisbi_app_get_active_window (NULL));
+		static GtkTargetEntry row_targets[] = {{(gchar*)"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0}};
 
 		/* create the model */
 		list_store = gsb_partial_balance_create_model ();
@@ -285,16 +266,20 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 		/* init the treeview */
 		treeview = priv->treeview_partial_balance;
 		gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (list_store));
-		gtk_widget_set_name (treeview, "tree_view");
+		gtk_widget_set_name (treeview, "colorized_tree_view");
 		g_object_set_data (G_OBJECT (priv->vbox_accueil), "treeview", treeview);
 		g_object_unref (list_store);
 
 		/* Enable drag & drop */
 		gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW (treeview),
-							GDK_BUTTON1_MASK, row_targets, 1,
-							GDK_ACTION_MOVE);
-		gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (treeview), row_targets,
-							1, GDK_ACTION_MOVE);
+												GDK_BUTTON1_MASK,
+												row_targets,
+												1,
+												GDK_ACTION_MOVE);
+		gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (treeview),
+											  row_targets,
+											  1,
+											  GDK_ACTION_MOVE);
 		gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview), TRUE);
 
 		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
@@ -370,10 +355,7 @@ static void prefs_page_accueil_setup_accueil_page (PrefsPageAccueil *page)
 		src_iface = GTK_TREE_DRAG_SOURCE_GET_IFACE (list_store);
 		if (src_iface)
 		{
-			gtk_selection_add_target (window,
-						  GDK_SELECTION_PRIMARY,
-						  GDK_SELECTION_TYPE_ATOM,
-						  1);
+			gtk_selection_add_target (treeview, GDK_SELECTION_PRIMARY, GDK_SELECTION_TYPE_ATOM, 1);
 			src_iface -> drag_data_get = &gsb_data_partial_balance_drag_data_get;
 		}
 
@@ -411,7 +393,6 @@ static void prefs_page_accueil_class_init (PrefsPageAccueilClass *klass)
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, box_lang_fr);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, hbox_paddingbox_lang_fr);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, checkbutton_balances_with_scheduled);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, eventbox_balances_with_scheduled);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, hbox_paddingbox_partial_balance);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, treeview_partial_balance);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, vbox_loading_partial_balance);
@@ -419,16 +400,11 @@ static void prefs_page_accueil_class_init (PrefsPageAccueilClass *klass)
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, button_partial_balance_edit);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, button_partial_balance_remove);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, checkbutton_partial_balance);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageAccueil, eventbox_partial_balance);
 
 	/* set callback functions */
 	gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass), gsb_partial_balance_add);
 	gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass), gsb_partial_balance_edit);
 	gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass), gsb_partial_balance_remove);
-	gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass),
-											 prefs_page_accueil_checkbutton_partial_balance_toggle);
-	gtk_widget_class_bind_template_callback (GTK_WIDGET_CLASS (klass),
-											 prefs_page_accueil_checkbutton_balances_with_scheduled_toggle);
 }
 
 /******************************************************************************/
