@@ -6,7 +6,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
 /*          2008-2017 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          http://www.grisbi.org                                                */
+/*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -39,7 +39,7 @@
 /*START_INCLUDE*/
 #include "prefs_page_archives.h"
 #include "dialog.h"
-#include "grisbi_settings.h"
+#include "grisbi_app.h"
 #include "gsb_account_property.h"
 #include "gsb_autofunc.h"
 #include "gsb_data_account.h"
@@ -56,6 +56,7 @@
 #include "utils.h"
 #include "utils_dates.h"
 #include "utils_prefs.h"
+#include "utils_str.h"
 #include "erreur.h"
 
 /*END_INCLUDE*/
@@ -71,7 +72,6 @@ struct _PrefsPageArchivesPrivate
 
 	GtkWidget *			treeview_archives;
     GtkWidget *			checkbutton_archives_sort_order;
-	GtkWidget *			eventbox_archives_sort_order;
 
 	GtkWidget *			grid_archives_modification;
 	GtkWidget *			entry_archives_name;
@@ -79,7 +79,6 @@ struct _PrefsPageArchivesPrivate
 	GtkWidget * 		button_archives_destroy;
 
 	GtkWidget *			checkbutton_archives_check_auto;
-	GtkWidget *			eventbox_archives_check_auto;
     GtkWidget *         spinbutton_archives_check_auto;
 
 };
@@ -147,7 +146,7 @@ static gboolean prefs_page_archives_delete_archive (GtkWidget *button,
 							  "All the information about that archive will be destroyed.\n\n"
 							  "Do you want to continue?"),
 							gsb_data_archive_get_name (archive_number));
-		if (!question_yes_no (tmp_str, _("Deleting an archive"), GTK_RESPONSE_CANCEL))
+		if (!dialogue_yes_no (tmp_str, _("Deleting an archive"), GTK_RESPONSE_CANCEL))
 		{
 			g_free (tmp_str);
 			return FALSE;
@@ -217,7 +216,7 @@ static gboolean prefs_page_archives_destroy_archive (GtkWidget *button,
 									  "continue ?"),
 								   gsb_data_archive_get_name (archive_number));
 
-		if (!question_yes_no (tmp_str, _("Deleting an archive and its transactions"), GTK_RESPONSE_CANCEL))
+		if (!dialogue_yes_no (tmp_str, _("Deleting an archive and its transactions"), GTK_RESPONSE_CANCEL))
 		{
 			g_free (tmp_str);
 			return FALSE;
@@ -393,20 +392,33 @@ static void prefs_page_archives_fill_list (GtkListStore *store)
 		GtkTreeIter iter;
 		gchar *init_date;
 		gchar *final_date;
+		const gchar *arch_name;
+		const gchar *report_name;
+		gchar *tmp_str1;
+		gchar *tmp_str2;
 
 		archive_number = gsb_data_archive_get_no_archive (tmp_list->data);
 
 		init_date = gsb_format_gdate (gsb_data_archive_get_beginning_date (archive_number));
 		final_date = gsb_format_gdate (gsb_data_archive_get_end_date (archive_number));
 
+		arch_name = gsb_data_archive_get_name (archive_number);
+		tmp_str1 = utils_str_break_form_name_field (arch_name, TRUNC_FORM_FIELD);
+
+		report_name = gsb_data_archive_get_report_title (archive_number);
+		if (report_name)
+			tmp_str2 = utils_str_break_form_name_field (report_name, TRUNC_FORM_FIELD);
+		else
+			tmp_str2 = NULL;
+
 		gtk_list_store_append (GTK_LIST_STORE (store), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (store),
 							&iter,
-							ARCHIVES_NAME_COLUMN, gsb_data_archive_get_name (archive_number),
+							ARCHIVES_NAME_COLUMN, tmp_str1,
 							ARCHIVES_INIT_DATE, init_date,
 							ARCHIVES_FINAL_DATE, final_date,
 							ARCHIVES_FYEAR_NAME, gsb_data_fyear_get_name (gsb_data_archive_get_fyear (archive_number)),
-							ARCHIVES_REPORT_TITLE, gsb_data_archive_get_report_title (archive_number),
+							ARCHIVES_REPORT_TITLE, tmp_str2,
 							ARCHIVES_NUMBER, archive_number,
 							-1);
 
@@ -414,6 +426,10 @@ static void prefs_page_archives_fill_list (GtkListStore *store)
 			g_free (init_date);
 		if (final_date)
 			g_free (final_date);
+		if (tmp_str1)
+			g_free (tmp_str1);
+		if (tmp_str2)
+			g_free (tmp_str2);
 
 		tmp_list = tmp_list->next;
     }
@@ -430,14 +446,11 @@ static void prefs_page_archives_fill_list (GtkListStore *store)
 static void prefs_page_archives_button_sort_order_clicked (GtkWidget *toggle_button,
 														   GtkWidget *treeview)
 {
-	GSettings *settings;
     GtkTreeModel *model;
 	gboolean is_loading;
+	GrisbiAppConf *a_conf;
 
-	settings = grisbi_settings_get_settings (SETTINGS_PREFS);
-	g_settings_set_int ( G_SETTINGS (settings),
-                        "prefs-archives-sort-order",
-                        conf.prefs_archives_sort_order);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
 	is_loading = grisbi_win_file_is_loading ();
 	if (is_loading)
@@ -445,9 +458,10 @@ static void prefs_page_archives_button_sort_order_clicked (GtkWidget *toggle_but
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
 		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
 											  ARCHIVES_FYEAR_NAME,
-											  conf.prefs_archives_sort_order);
+											  a_conf->prefs_archives_sort_order);
 		gtk_tree_sortable_sort_column_changed (GTK_TREE_SORTABLE (model));
 		prefs_page_archives_fill_list (GTK_LIST_STORE (model));
+    	utils_set_list_store_background_color (treeview, ARCHIVES_BACKGROUND_COLOR);
 	}
 }
 
@@ -458,23 +472,20 @@ static void prefs_page_archives_button_sort_order_clicked (GtkWidget *toggle_but
  *
  * \return
  **/
-static void prefs_page_archives_setup_treeview_archives (PrefsPageArchives *page)
+static void prefs_page_archives_setup_treeview_archives (PrefsPageArchives *page,
+														 GrisbiAppConf *a_conf)
 {
 	PrefsPageArchivesPrivate *priv;
     GtkListStore *archives_model;
 	GtkTreeSelection *selection;
     gint i;
-    gchar *titles[] = {
-	_("Name"), _("Initial date"), _("Final date"), _("Financial year"), _("Report name") };
+    const gchar *titles[] = {
+	N_("Name"), N_("Initial date"), N_("Final date"), N_("Financial year"), N_("Report name") };
     gfloat alignment[] = {
 	COLUMN_LEFT, COLUMN_CENTER, COLUMN_CENTER , COLUMN_CENTER, COLUMN_CENTER };
 
-	devel_debug (NULL);
-
 	priv = prefs_page_archives_get_instance_private (page);
 
-	gtk_widget_set_name (priv->treeview_archives, "tree_view");
-
 	/* Create tree model */
     archives_model = gtk_list_store_new (NUM_ARCHIVES_COLUMNS,
 										 G_TYPE_STRING,
@@ -501,7 +512,7 @@ static void prefs_page_archives_setup_treeview_archives (PrefsPageArchives *page
         gtk_tree_view_column_set_alignment (column, alignment[i]);
 
         gtk_tree_view_column_pack_start (column, cell, TRUE);
-        gtk_tree_view_column_set_title (column, titles[i]);
+        gtk_tree_view_column_set_title (column, gettext (titles[i]));
         gtk_tree_view_column_set_attributes (column,
 											 cell,
 											 "text", i,
@@ -515,7 +526,7 @@ static void prefs_page_archives_setup_treeview_archives (PrefsPageArchives *page
     /* Sort columns accordingly */
     gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (archives_model),
                                           ARCHIVES_FYEAR_NAME,
-                                          conf.prefs_archives_sort_order);
+                                          a_conf->prefs_archives_sort_order);
 
 	/* fill the list */
     prefs_page_archives_fill_list (archives_model);
@@ -539,16 +550,18 @@ static void prefs_page_archives_setup_treeview_archives (PrefsPageArchives *page
  *
  * \return
  */
-static void prefs_page_archives_setup_archives_page (PrefsPageArchives *page)
+static void prefs_page_archives_setup_page (PrefsPageArchives *page)
 {
 	GtkWidget *head_page;
 	gchar* tmp_str;
 	gboolean is_loading;
+	GrisbiAppConf *a_conf;
 	PrefsPageArchivesPrivate *priv;
 
 	devel_debug (NULL);
 
 	priv = prefs_page_archives_get_instance_private (page);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 	is_loading = grisbi_win_file_is_loading ();
 
 	/* On récupère le nom de la page */
@@ -557,18 +570,18 @@ static void prefs_page_archives_setup_archives_page (PrefsPageArchives *page)
 	gtk_box_reorder_child (GTK_BOX (priv->vbox_archives), head_page, 0);
 
 	/* set the entry widget entry_archives_name */
-	priv->entry_archives_name = gsb_autofunc_entry_new (NULL,
-												  G_CALLBACK (prefs_page_archives_name_changed),
-												  priv->treeview_archives,
-												  G_CALLBACK (gsb_data_archive_set_name),
-												  0);
-
-    gtk_grid_attach (GTK_GRID (priv->grid_archives_modification), priv->entry_archives_name, 1,0, 1, 1);
+	gsb_autofunc_entry_new_from_ui (priv->entry_archives_name,
+	                                NULL,
+								    G_CALLBACK (prefs_page_archives_name_changed),
+								    priv->treeview_archives,
+								    G_CALLBACK (gsb_data_archive_set_name),
+								    0);
+	gtk_widget_set_margin_bottom (priv->entry_archives_name, MARGIN_BOX);
 
 	/* setup treeview_archives */
 	if (is_loading)
 	{
-		prefs_page_archives_setup_treeview_archives (page);
+		prefs_page_archives_setup_treeview_archives (page, a_conf);
 	}
 	else
 	{
@@ -580,18 +593,13 @@ static void prefs_page_archives_setup_archives_page (PrefsPageArchives *page)
 
     /* set the checkbutton to sort archives */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_archives_sort_order),
-								  conf.prefs_archives_sort_order);
+								  a_conf->prefs_archives_sort_order);
 
     /* Connect signal */
-    g_signal_connect (priv->eventbox_archives_sort_order,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_archives_sort_order);
-
     g_signal_connect (priv->checkbutton_archives_sort_order,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.prefs_archives_sort_order);
+					  &a_conf->prefs_archives_sort_order);
 
 	g_signal_connect_after (priv->checkbutton_archives_sort_order,
 							"toggled",
@@ -620,24 +628,19 @@ static void prefs_page_archives_setup_archives_page (PrefsPageArchives *page)
 
 	/* set the checkbutton for the automatic check */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_archives_check_auto),
-								  conf.archives_check_auto);
+								  a_conf->archives_check_auto);
 
 	/* Connect signal */
-    g_signal_connect (priv->eventbox_archives_check_auto,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_archives_check_auto);
-
     g_signal_connect (priv->checkbutton_archives_check_auto,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.archives_check_auto);
+					  &a_conf->archives_check_auto);
 
 	/* set the max of transactions before archival and state */
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->spinbutton_archives_check_auto),
-							   conf.max_non_archived_transactions_for_check);
+							   a_conf->max_non_archived_transactions_for_check);
 
-	if (!conf.archives_check_auto)
+	if (!a_conf->archives_check_auto)
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->spinbutton_archives_check_auto), FALSE);
 
     /* callback for spinbutton_ */
@@ -649,7 +652,7 @@ static void prefs_page_archives_setup_archives_page (PrefsPageArchives *page)
     g_signal_connect (priv->spinbutton_archives_check_auto,
 					  "value-changed",
 					  G_CALLBACK (utils_prefs_spinbutton_changed),
-					  &conf.max_non_archived_transactions_for_check);
+					  &a_conf->max_non_archived_transactions_for_check);
 }
 
 /******************************************************************************/
@@ -659,7 +662,7 @@ static void prefs_page_archives_init (PrefsPageArchives *page)
 {
 	gtk_widget_init_template (GTK_WIDGET (page));
 
-	prefs_page_archives_setup_archives_page (page);
+	prefs_page_archives_setup_page (page);
 }
 
 static void prefs_page_archives_dispose (GObject *object)
@@ -678,14 +681,13 @@ static void prefs_page_archives_class_init (PrefsPageArchivesClass *klass)
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, treeview_archives);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, checkbutton_archives_sort_order);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, eventbox_archives_sort_order);
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, grid_archives_modification);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, button_archives_delete);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, button_archives_destroy);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, entry_archives_name);
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, checkbutton_archives_check_auto);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, eventbox_archives_check_auto);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageArchives, spinbutton_archives_check_auto);
 }
 
