@@ -6,7 +6,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
 /*          2008-2018 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          http://www.grisbi.org                                                */
+/*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -58,32 +58,24 @@ struct _PrefsPageFilesPrivate
 	GtkWidget *			vbox_files;
 
     GtkWidget *			checkbutton_load_last_file;
-	GtkWidget *			eventbox_load_last_file;
     GtkWidget *         checkbutton_sauvegarde_auto;
-	GtkWidget *			eventbox_sauvegarde_auto;
     GtkWidget *         checkbutton_force_enregistrement;
-	GtkWidget *			eventbox_force_enregistrement;
     GtkWidget *         checkbutton_compress_file;
-	GtkWidget *			eventbox_compress_file;
     GtkWidget *         checkbutton_crypt_file;
-	GtkWidget *			eventbox_crypt_file;
+	GtkWidget *			label_nb_max_derniers_fichiers;
 	GtkWidget *         spinbutton_nb_max_derniers_fichiers;
 
     GtkWidget *         checkbutton_make_bakup_single_file;
-	GtkWidget *			eventbox_make_bakup_single_file;
     GtkWidget *         checkbutton_compress_backup;
-	GtkWidget *			eventbox_compress_backup;
     GtkWidget *         checkbutton_sauvegarde_demarrage;
-	GtkWidget *			eventbox_sauvegarde_demarrage;
     GtkWidget *         checkbutton_make_backup;
-	GtkWidget *			eventbox_make_backup;
     GtkWidget *         checkbutton_make_backup_every_minutes;
-	GtkWidget *			eventbox_make_backup_every_minutes;
     GtkWidget *         spinbutton_make_backup_nb_minutes;
+    GtkWidget *         checkbutton_remove_backup_files;
+    GtkWidget *         spinbutton_remove_backup_months;
     GtkWidget *         filechooserbutton_backup;
 
     GtkWidget *			checkbutton_force_import_directory;
-	GtkWidget *			eventbox_force_import_directory;
     GtkWidget *         filechooserbutton_force_import_directory;
 };
 
@@ -103,6 +95,7 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 {
 	GtkWidget *head_page;
 	gboolean is_loading;
+	GrisbiAppConf *a_conf;
 	GrisbiWinEtat *w_etat;
 	PrefsPageFilesPrivate *priv;
 
@@ -110,6 +103,7 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 
 	priv = prefs_page_files_get_instance_private (page);
 	is_loading = grisbi_win_file_is_loading ();
+	a_conf = grisbi_app_get_a_conf ();
 	w_etat = grisbi_win_get_w_etat ();
 
 	/* On récupère le nom de la page */
@@ -119,61 +113,41 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 
     /* set the variables for account */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_load_last_file),
-								  conf.dernier_fichier_auto);
+								  a_conf->dernier_fichier_auto);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_sauvegarde_auto),
-								  conf.sauvegarde_auto);
+								  a_conf->sauvegarde_auto);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_force_enregistrement),
-								  conf.force_enregistrement);
+								  a_conf->force_enregistrement);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_compress_file),
-								  conf.compress_file);
+								  a_conf->compress_file);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_crypt_file),
 								  w_etat->crypt_file);
 	gtk_widget_set_sensitive (priv->checkbutton_crypt_file, is_loading);
 
 	/* set the max number of files */
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->spinbutton_nb_max_derniers_fichiers),
-							   conf.nb_max_derniers_fichiers_ouverts);
+							   a_conf->nb_max_derniers_fichiers_ouverts);
 
     /* Connect signal */
-    g_signal_connect (priv->eventbox_load_last_file,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_load_last_file);
-
     g_signal_connect (priv->checkbutton_load_last_file,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.dernier_fichier_auto);
-
-    g_signal_connect (priv->eventbox_sauvegarde_auto,
-                      "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-                      priv->checkbutton_sauvegarde_auto);
+					  &a_conf->dernier_fichier_auto);
 
     g_signal_connect (priv->checkbutton_sauvegarde_auto,
                       "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-                      &conf.sauvegarde_auto);
-
-    g_signal_connect (priv->eventbox_force_enregistrement,
-                      "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-                      priv->checkbutton_force_enregistrement);
+                      &a_conf->sauvegarde_auto);
 
     g_signal_connect (priv->checkbutton_force_enregistrement,
                       "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-                      &conf.force_enregistrement);
-
-    g_signal_connect (priv->eventbox_compress_file,
-                      "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-                      priv->checkbutton_compress_file);
+                      &a_conf->force_enregistrement);
 
     g_signal_connect (priv->checkbutton_compress_file,
                       "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-                      &conf.compress_file);
+                      &a_conf->compress_file);
 
 #ifdef HAVE_SSL
 	g_signal_connect (priv->checkbutton_crypt_file,
@@ -181,14 +155,9 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
 					  &w_etat->crypt_file);
 
-	g_signal_connect (priv->eventbox_crypt_file,
-                      "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-                      priv->checkbutton_crypt_file);
-
 	g_signal_connect_after (priv->checkbutton_crypt_file,
 							"toggled",
-							G_CALLBACK (gsb_gui_encryption_toggled),
+							G_CALLBACK (utils_prefs_encryption_toggled),
 							NULL);
 #endif
 
@@ -196,7 +165,7 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
     g_signal_connect (priv->spinbutton_nb_max_derniers_fichiers,
                         "value-changed",
                         G_CALLBACK (utils_prefs_spinbutton_changed),
-                        &conf.nb_max_derniers_fichiers_ouverts);
+                        &a_conf->nb_max_derniers_fichiers_ouverts);
 
 	g_signal_connect_after (priv->spinbutton_nb_max_derniers_fichiers,
                         "value-changed",
@@ -205,19 +174,24 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 
     /* set the variables for backup tab */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_make_bakup_single_file),
-								  conf.make_bakup_single_file);
+								  a_conf->make_bakup_single_file);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_compress_backup),
-								  conf.compress_backup);
+								  a_conf->compress_backup);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_sauvegarde_demarrage),
-								  conf.sauvegarde_demarrage);
+								  a_conf->sauvegarde_demarrage);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_make_backup),
-								  conf.make_backup);
+								  a_conf->sauvegarde_fermeture);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_make_backup_every_minutes),
-								  conf.make_backup_every_minutes);
-
+								  a_conf->make_backup_every_minutes);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_remove_backup_files),
+								  a_conf->remove_backup_files);
     /* set minutes */
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->spinbutton_make_backup_nb_minutes),
-							   conf.make_backup_nb_minutes);
+							   a_conf->make_backup_nb_minutes);
+
+	/* set months */
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->spinbutton_remove_backup_months),
+							   a_conf->remove_backup_months);
 
     /* set current folder for backup files */
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (priv->filechooserbutton_backup),
@@ -225,10 +199,10 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 
     /* set current folder for import files */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_force_import_directory),
-								  conf.force_import_directory);
-	if (conf.import_directory)
+								  a_conf->force_import_directory);
+	if (a_conf->import_directory)
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (priv->filechooserbutton_force_import_directory),
-											 conf.import_directory);
+											 a_conf->import_directory);
 	else
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->filechooserbutton_force_import_directory), FALSE);
 
@@ -237,89 +211,78 @@ static void prefs_page_files_setup_files_page (PrefsPageFiles *page)
 					   priv->filechooserbutton_force_import_directory);
 
     /* Connect signal */
-    g_signal_connect (priv->eventbox_make_bakup_single_file,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_make_bakup_single_file);
-
     g_signal_connect (priv->checkbutton_make_bakup_single_file,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.make_bakup_single_file);
-
-    g_signal_connect (priv->eventbox_compress_backup,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_compress_backup);
+					  &a_conf->make_bakup_single_file);
 
     g_signal_connect (priv->checkbutton_compress_backup,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-                      &conf.compress_backup);
-
-    g_signal_connect (priv->eventbox_sauvegarde_demarrage,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-                      priv->checkbutton_sauvegarde_demarrage);
+                      &a_conf->compress_backup);
 
     g_signal_connect (priv->checkbutton_sauvegarde_demarrage,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-                      &conf.sauvegarde_demarrage);
-
-    g_signal_connect (priv->eventbox_make_backup,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-                      priv->checkbutton_make_backup);
+                      &a_conf->sauvegarde_demarrage);
 
     g_signal_connect (priv->checkbutton_make_backup,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-                      &conf.make_backup);
-
-    g_signal_connect (priv->eventbox_make_backup_every_minutes,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-                      priv->checkbutton_make_backup_every_minutes);
+                      &a_conf->sauvegarde_fermeture);
 
     g_signal_connect (priv->checkbutton_make_backup_every_minutes,
                       "toggled",
                       G_CALLBACK (utils_prefs_page_checkbutton_changed),
-                      &conf.make_backup_every_minutes);
+                      &a_conf->make_backup_every_minutes);
+
+    g_signal_connect (priv->checkbutton_remove_backup_files,
+                      "toggled",
+                      G_CALLBACK (utils_prefs_page_checkbutton_changed),
+                      &a_conf->remove_backup_files);
 
     /* callback for spinbutton_make_backup_nb_minutes */
     g_object_set_data (G_OBJECT (priv->spinbutton_make_backup_nb_minutes),
                        "button", priv->checkbutton_make_backup_every_minutes);
 	g_object_set_data (G_OBJECT (priv->checkbutton_make_backup_every_minutes),
                        "widget", priv->spinbutton_make_backup_nb_minutes);
-	if (!conf.make_backup_every_minutes)
+	if (!a_conf->make_backup_every_minutes)
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->spinbutton_make_backup_nb_minutes), FALSE);
 
     g_signal_connect (priv->spinbutton_make_backup_nb_minutes,
 					  "value-changed",
 					  G_CALLBACK (utils_prefs_spinbutton_changed),
-					  &conf.make_backup_nb_minutes);
+					  &a_conf->make_backup_nb_minutes);
+
+    /* callback for spinbutton_remove_backup_months */
+    g_object_set_data (G_OBJECT (priv->spinbutton_remove_backup_months),
+                       "button", priv->checkbutton_remove_backup_files);
+	g_object_set_data (G_OBJECT (priv->checkbutton_remove_backup_files),
+                       "widget", priv->spinbutton_remove_backup_months);
+	if (!a_conf->remove_backup_files)
+		gtk_widget_set_sensitive (GTK_WIDGET (priv->spinbutton_remove_backup_months), FALSE);
+
+    g_signal_connect (priv->spinbutton_remove_backup_months,
+					  "value-changed",
+					  G_CALLBACK (utils_prefs_spinbutton_changed),
+					  &a_conf->remove_backup_months);
 
     /* connect the signal for filechooserbutton_backup */
     g_signal_connect (G_OBJECT (priv->filechooserbutton_backup),
                       "selection-changed",
                       G_CALLBACK (utils_prefs_page_dir_chosen),
-                      "backup_path");
+                      (gpointer) "backup_path");
 
-    g_signal_connect (priv->eventbox_force_import_directory,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_force_import_directory);
     g_signal_connect (priv->checkbutton_force_import_directory,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.force_import_directory);
+					  &a_conf->force_import_directory);
 
     /* connect the signal for filechooserbutton_force_import_directory */
     g_signal_connect (G_OBJECT (priv->filechooserbutton_force_import_directory),
                       "selection-changed",
                       G_CALLBACK (utils_prefs_page_dir_chosen),
-                      "import_directory");
+                      (gpointer) "import_directory");
 }
 
 /******************************************************************************/
@@ -346,32 +309,24 @@ static void prefs_page_files_class_init (PrefsPageFilesClass *klass)
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, vbox_files);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_load_last_file);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_load_last_file);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_sauvegarde_auto);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_sauvegarde_auto);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_force_enregistrement);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_force_enregistrement);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_compress_file);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_compress_file);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_crypt_file);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_crypt_file);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, label_nb_max_derniers_fichiers);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, spinbutton_nb_max_derniers_fichiers);
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_make_bakup_single_file);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_make_bakup_single_file);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_compress_backup);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_compress_backup);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_sauvegarde_demarrage);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_sauvegarde_demarrage);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_make_backup);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_make_backup);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_make_backup_every_minutes);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_make_backup_every_minutes);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, spinbutton_make_backup_nb_minutes);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_remove_backup_files);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, spinbutton_remove_backup_months);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, filechooserbutton_backup);
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, checkbutton_force_import_directory);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, eventbox_force_import_directory);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFiles, filechooserbutton_force_import_directory);
 }
 
