@@ -5,8 +5,8 @@
 /*                                                                               */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
-/*          2008-2018 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          http://www.grisbi.org                                                */
+/*          2008-2020 Pierre Biava (grisbi@pierre.biava.name)                    */
+/*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 
 /*START_INCLUDE*/
 #include "prefs_page_form_completion.h"
-#include "grisbi_settings.h"
+#include "grisbi_app.h"
 #include "gsb_category.h"
 #include "gsb_data_form.h"
 #include "gsb_file.h"
@@ -64,36 +64,20 @@ struct _PrefsPageFormCompletionPrivate
 {
 	GtkWidget *			vbox_form_completion;
 
-	GtkWidget *			hbox_combofix_case_sensitive;
     GtkWidget *			checkbutton_combofix_case_sensitive;
-	GtkWidget *			eventbox_combofix_case_sensitive;
 
 	GtkWidget *			spinbutton_completion_minimum_key_length;
 
 	GtkWidget *			hbox_automatic_completion_payee;
 	GtkWidget *			checkbutton_automatic_completion_payee;
-	GtkWidget *			eventbox_automatic_completion_payee;
-
 	GtkWidget *			checkbutton_automatic_erase_credit_debit;
-	GtkWidget *			eventbox_automatic_erase_credit_debit;
-
 	GtkWidget *			checkbutton_automatic_recover_splits;
-	GtkWidget *			eventbox_automatic_recover_splits;
-
 	GtkWidget *			checkbutton_limit_completion_to_current_account;
-	GtkWidget *			eventbox_limit_completion_to_current_account;
 
-	GtkWidget *			hbox_combofix_force_payee;
 	GtkWidget *			checkbutton_combofix_force_payee;
-	GtkWidget *			eventbox_combofix_force_payee;
-
-	GtkWidget *			hbox_combofix_mixed_sort;
 	GtkWidget *			checkbutton_combofix_mixed_sort;
-	GtkWidget *			eventbox_combofix_mixed_sort;
 
-	GtkWidget *			hbox_combofix_force_category;
 	GtkWidget *			checkbutton_combofix_force_category;
-	GtkWidget *			eventbox_combofix_force_category;
 
 };
 
@@ -164,69 +148,6 @@ static void prefs_page_form_completion_update_combofix (GtkWidget *checkbutton,
 	}
 }
 
-/**
- *
- *
- * \param
- *
- * \return
- **/
-static void prefs_page_form_completion_save_checkbuton_value (GtkWidget *button)
-{
-	const gchar *tmp_name;
-	GSettings *settings;
-
-	settings = grisbi_settings_get_settings (SETTINGS_FORM);
-	tmp_name = gtk_widget_get_name (button);
-	if (strcmp (tmp_name, "checkbutton_automatic_completion_payee") ==0)
-	{
-		if (conf.automatic_completion_payee)
-			g_settings_set_boolean (G_SETTINGS (settings), "automatic-completion-payee", TRUE);
-		else
-			g_settings_reset (G_SETTINGS (settings), "automatic-completion-payee");
-
-		return;
-	}
-	if (strcmp (tmp_name, "checkbutton_automatic_erase_credit_debit") == 0)
-	{
-		if (conf.automatic_erase_credit_debit)
-			g_settings_set_boolean (G_SETTINGS (settings), "automatic-erase-credit-debit", TRUE);
-		else
-			g_settings_reset (G_SETTINGS (settings), "automatic-erase-credit-debit");
-
-		return;
-	}
-	if (strcmp (tmp_name, "checkbutton_automatic_recover_splits") == 0)
-	{
-		if (conf.automatic_recover_splits)
-			g_settings_set_boolean (G_SETTINGS (settings), "automatic-recover-splits", TRUE);
-		else
-			g_settings_reset (G_SETTINGS (settings), "automatic-recover-splits");
-
-		return;
-	}
-	if (strcmp (tmp_name, "checkbutton_limit_completion_to_current_account") == 0)
-	{
-		if (conf.limit_completion_to_current_account)
-			g_settings_set_boolean (G_SETTINGS (settings), "limit-completion-current-account", TRUE);
-		else
-			g_settings_reset (G_SETTINGS (settings), "limit-completion-current-account");
-
-		return;
-	}
-	if (strcmp (tmp_name, "spinbutton_completion_minimum_key_length") == 0)
-	{
-		if (conf.completion_minimum_key_length > 1)
-			g_settings_set_int (G_SETTINGS (settings),
-								"completion-minimum-key-length",
-								conf.completion_minimum_key_length);
-		else
-			g_settings_reset (G_SETTINGS (settings), "completion-minimum-key-length");
-
-		return;
-	}
-}
-
 /**
  * Appellée lorsqu'on coche la case "Automatic filling transactions from payee"
  *
@@ -255,7 +176,6 @@ static void prefs_page_form_completion_checkbutton_automatic_completion_payee_to
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_limit_completion_to_current_account),
 									  FALSE);
     }
-	prefs_page_form_completion_save_checkbuton_value (checkbutton);
 }
 
 /**
@@ -272,29 +192,30 @@ static void prefs_page_form_completion_spinbutton_completion_minimum_key_length_
     GtkWidget *combofix;
 	GtkWidget *entry;
 	GtkEntryCompletion *completion;
+	GrisbiAppConf *a_conf;
 
+	a_conf = grisbi_app_get_a_conf ();
 	combofix = gsb_form_widget_get_widget (TRANSACTION_FORM_PARTY);
 	if (combofix && GTK_IS_COMBOFIX (combofix))
 	{
 		entry = gtk_combofix_get_entry (GTK_COMBOFIX (combofix));
 		completion = gtk_entry_get_completion (GTK_ENTRY (entry));
-		gtk_entry_completion_set_minimum_key_length (completion, conf.completion_minimum_key_length);
+		gtk_entry_completion_set_minimum_key_length (completion, a_conf->completion_minimum_key_length);
 	}
 	combofix = gsb_form_widget_get_widget (TRANSACTION_FORM_CATEGORY);
 	if (combofix && GTK_IS_COMBOFIX (combofix))
 	{
 		entry = gtk_combofix_get_entry (GTK_COMBOFIX (combofix));
 		completion = gtk_entry_get_completion (GTK_ENTRY (entry));
-		gtk_entry_completion_set_minimum_key_length (completion, conf.completion_minimum_key_length);
+		gtk_entry_completion_set_minimum_key_length (completion, a_conf->completion_minimum_key_length);
 	}
 	combofix = gsb_form_widget_get_widget (TRANSACTION_FORM_BUDGET);
 	if (combofix && GTK_IS_COMBOFIX (combofix))
 	{
 		entry = gtk_combofix_get_entry (GTK_COMBOFIX (combofix));
 		completion = gtk_entry_get_completion (GTK_ENTRY (entry));
-		gtk_entry_completion_set_minimum_key_length (completion, conf.completion_minimum_key_length);
+		gtk_entry_completion_set_minimum_key_length (completion, a_conf->completion_minimum_key_length);
 	}
-	prefs_page_form_completion_save_checkbuton_value (spinbutton);
 }
 
 /**
@@ -308,12 +229,14 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
 {
 	GtkWidget *head_page;
 	gboolean is_loading;
+	GrisbiAppConf *a_conf;
 	PrefsPageFormCompletionPrivate *priv;
 
 	devel_debug (NULL);
 
 	priv = prefs_page_form_completion_get_instance_private (page);
 	is_loading = grisbi_win_file_is_loading ();
+	a_conf = grisbi_app_get_a_conf ();
 
 	/* On récupère le nom de la page */
 	head_page = utils_prefs_head_page_new_with_title_and_icon (_("Form completion"), "gsb-form-32.png");
@@ -322,7 +245,7 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
 
 	/* initialise le bouton nombre minimal de caractères avant propositions dans les champs de saisie */
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->spinbutton_completion_minimum_key_length),
-							   conf.completion_minimum_key_length);
+							   a_conf->completion_minimum_key_length);
 
 	/* set active widgets if is_loading = TRUE else set sensitive widget*/
 	if (is_loading)
@@ -342,35 +265,30 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
 	}
 	else
 	{
-		gtk_widget_set_sensitive (priv->hbox_combofix_mixed_sort, FALSE);
-		gtk_widget_set_sensitive (priv->hbox_combofix_case_sensitive, FALSE);
-		gtk_widget_set_sensitive (priv->hbox_combofix_force_payee, FALSE);
-		gtk_widget_set_sensitive (priv->hbox_combofix_force_category, FALSE);
+		gtk_widget_set_sensitive (priv->checkbutton_combofix_mixed_sort, FALSE);
+		gtk_widget_set_sensitive (priv->checkbutton_combofix_case_sensitive, FALSE);
+		gtk_widget_set_sensitive (priv->checkbutton_combofix_force_payee, FALSE);
+		gtk_widget_set_sensitive (priv->checkbutton_combofix_force_category, FALSE);
 	}
 
-	/* set conf.automatic_completion_payee */
+	/* set a_conf->automatic_completion_payee */
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_automatic_completion_payee),
-								  conf.automatic_completion_payee);
-	if (!conf.automatic_completion_payee)
+								  a_conf->automatic_completion_payee);
+	if (!a_conf->automatic_completion_payee)
 	{
 		gtk_widget_set_sensitive (priv->hbox_automatic_completion_payee, FALSE);
 	}
 	else
 	{
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_automatic_erase_credit_debit),
-									  conf.automatic_erase_credit_debit);
+									  a_conf->automatic_erase_credit_debit);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_automatic_recover_splits),
-									  conf.automatic_recover_splits);
+									  a_conf->automatic_recover_splits);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_limit_completion_to_current_account),
-									  conf.limit_completion_to_current_account);
+									  a_conf->limit_completion_to_current_account);
 	}
 
     /* Connect signal checkbutton_combofix_case_sensitive */
-    g_signal_connect (priv->eventbox_combofix_case_sensitive,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_combofix_case_sensitive);
-
     g_signal_connect (priv->checkbutton_combofix_case_sensitive,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
@@ -385,7 +303,7 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
     g_signal_connect (priv->spinbutton_completion_minimum_key_length,
 					  "value-changed",
 					  G_CALLBACK (utils_prefs_spinbutton_changed),
-					  &conf.completion_minimum_key_length);
+					  &a_conf->completion_minimum_key_length);
 
     g_signal_connect_after (priv->spinbutton_completion_minimum_key_length,
 							"value-changed",
@@ -393,15 +311,10 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
 							NULL);
 
 	/* Connect signal checkbutton_automatic_completion_payee */
-    g_signal_connect (priv->eventbox_automatic_completion_payee,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_automatic_completion_payee);
-
     g_signal_connect (priv->checkbutton_automatic_completion_payee,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.automatic_completion_payee);
+					  &a_conf->automatic_completion_payee);
 
     g_signal_connect_after (priv->checkbutton_automatic_completion_payee,
 							"toggled",
@@ -409,59 +322,24 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
 							page);
 
     /* Connect signal checkbutton_checkbutton_automatic_erase_credit_debit */
-    g_signal_connect (priv->eventbox_automatic_erase_credit_debit,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_automatic_erase_credit_debit);
-
     g_signal_connect (priv->checkbutton_automatic_erase_credit_debit,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.automatic_erase_credit_debit);
-
-    g_signal_connect_after (priv->checkbutton_automatic_erase_credit_debit,
-							"toggled",
-							G_CALLBACK (prefs_page_form_completion_save_checkbuton_value),
-							NULL);
+					  &a_conf->automatic_erase_credit_debit);
 
 	/* Connect signal checkbutton_checkbutton_automatic_recover_splits */
-    g_signal_connect (priv->eventbox_automatic_recover_splits,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_automatic_recover_splits);
-
 	g_signal_connect (priv->checkbutton_automatic_recover_splits,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.automatic_recover_splits);
-
-	g_signal_connect_after (priv->checkbutton_automatic_recover_splits,
-							"toggled",
-							G_CALLBACK (prefs_page_form_completion_save_checkbuton_value),
-							NULL);
+					  &a_conf->automatic_recover_splits);
 
     /* Connect signal checkbutton_checkbutton_limit_completion_to_current_account */
-    g_signal_connect (priv->eventbox_limit_completion_to_current_account,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_limit_completion_to_current_account);
-
     g_signal_connect (priv->checkbutton_limit_completion_to_current_account,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.limit_completion_to_current_account);
-
-    g_signal_connect_after (priv->checkbutton_limit_completion_to_current_account,
-							"toggled",
-							G_CALLBACK (prefs_page_form_completion_save_checkbuton_value),
-							NULL);
+					  &a_conf->limit_completion_to_current_account);
 
     /* Connect signal checkbutton_combofix_force_payee */
-    g_signal_connect (priv->eventbox_combofix_force_payee,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_combofix_force_payee);
-
     g_signal_connect (priv->checkbutton_combofix_force_payee,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
@@ -473,11 +351,6 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
 							GINT_TO_POINTER (METATREE_PAYEE));
 
     /* Connect signal checkbutton_combofix_mixed_sort */
-    g_signal_connect (priv->eventbox_combofix_mixed_sort,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_combofix_mixed_sort);
-
     g_signal_connect (priv->checkbutton_combofix_mixed_sort,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
@@ -489,11 +362,6 @@ static void prefs_page_form_completion_setup_form_completion_page (PrefsPageForm
 							GINT_TO_POINTER (METATREE_CATEGORY));
 
     /* Connect signal checkbutton_combofix_force_category */
-    g_signal_connect (priv->eventbox_combofix_force_category,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_combofix_force_category);
-
     g_signal_connect (priv->checkbutton_combofix_force_category,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
@@ -530,27 +398,15 @@ static void prefs_page_form_completion_class_init (PrefsPageFormCompletionClass
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, vbox_form_completion);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_combofix_case_sensitive);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_combofix_case_sensitive);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, hbox_combofix_case_sensitive);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, spinbutton_completion_minimum_key_length);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_automatic_completion_payee);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_automatic_completion_payee);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, hbox_automatic_completion_payee);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_automatic_erase_credit_debit);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_automatic_erase_credit_debit);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_automatic_recover_splits);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_automatic_recover_splits);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_limit_completion_to_current_account);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_limit_completion_to_current_account);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_combofix_force_payee);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_combofix_force_payee);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, hbox_combofix_force_payee);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_combofix_mixed_sort);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_combofix_mixed_sort);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, hbox_combofix_mixed_sort);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, checkbutton_combofix_force_category);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, eventbox_combofix_force_category);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageFormCompletion, hbox_combofix_force_category);
 }
 
 /******************************************************************************/
