@@ -27,8 +27,6 @@
 #define ETAT_WWW_BROWSER        "xdg-open"          /* définit le browser par défaut */
 #endif
 
-#define ETATS_MAX_OPES			3000				/* Nombre d'opérations sélectionnées avant avertissement */
-
 /* Nbre de messages de delete et de warnings */
 #define NBRE_MSG_WARNINGS		9
 #define NBRE_MSG_DELETE			7
@@ -306,7 +304,7 @@ struct _GrisbiAppConf
 /* scheduled part */
     gboolean    balances_with_scheduled;                    /* TRUE = the balance incorporates the scheduled operations */
     gboolean    execute_scheduled_of_month;                 /* warn/execute scheduled at expiration (FALSE) or of the month (TRUE) */
-	gboolean	last_selected_scheduler;					/* TRUE = last scheduler selected in list = default */
+	gboolean	select_scheduled_in_list;					/* TRUE = select last scheduled in list TRUE by default */
 	gint		nb_days_before_scheduled;					/* nombre de jours avant relance des opérations planifiées */
 	gboolean	scheduler_set_fixed_day;					/* Si coché le nombre est considéré comme un jour fixe */
 	gint		scheduler_fixed_day;
