@@ -4,7 +4,7 @@
 /*          2003-2004 Alain Portal (aportal@univ-montp2.fr)                   */
 /*          2003-2004 Francois Terrot (francois.terrot@grisbi.org)            */
 /*          2008-2017 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -42,10 +42,6 @@
 #include "erreur.h"
 /*END_INCLUDE*/
 
-#ifdef GTKOSXAPPLICATION
-#include "grisbi_osx.h"
-#endif  /* GTKOSXAPPLICATION */
-
 #ifdef G_OS_WIN32
 #include <windows.h>
 #endif  /* G_OS_WIN32 */
@@ -188,17 +184,20 @@ gboolean lance_navigateur_web (const gchar *url)
     gchar **split;
     gchar *chaine = NULL;
     gchar* tmp_str;
+	GrisbiAppConf *a_conf;
+
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
 #ifdef G_OS_WIN32
     gboolean use_default_browser = TRUE;
 
-    if (conf.browser_command && strlen (conf.browser_command))
+    if (a_conf->browser_command && strlen (a_conf->browser_command))
     {
-        use_default_browser = !strcmp (conf.browser_command,ETAT_WWW_BROWSER);
+        use_default_browser = !strcmp (a_conf->browser_command,ETAT_WWW_BROWSER);
     }
 
 #else /* G_OS_WIN32 */
-    if (!(conf.browser_command && strlen (conf.browser_command)))
+    if (!(a_conf->browser_command && strlen (a_conf->browser_command)))
     {
         tmp_str = g_strdup_printf (_("Grisbi was unable to execute a web browser to "
                         "browse url:\n<span foreground=\"blue\">%s</span>.\n\n"
@@ -216,7 +215,7 @@ gboolean lance_navigateur_web (const gchar *url)
 #endif /* G_OS_WIN32 */
         /* search if the sequence `%s' is in the string
          * and split the string before and after this delimiter */
-        split = g_strsplit (conf.browser_command, "%s", 0);
+        split = g_strsplit (a_conf->browser_command, "%s", 0);
 
         if (split[1])
         {
@@ -233,7 +232,7 @@ gboolean lance_navigateur_web (const gchar *url)
             chaine = tmp_str;
         }
         else
-            chaine = g_strconcat (conf.browser_command, " \"", url, "\"&", NULL);
+            chaine = g_strconcat (a_conf->browser_command, " \"", url, "\"&", NULL);
 
         if (system (chaine) == -1)
         {
@@ -285,6 +284,7 @@ GtkWidget *new_paddingbox_with_title (GtkWidget *parent,
     /* Creating label */
     label = gtk_label_new (NULL);
     utils_labels_set_alignment (GTK_LABEL (label), 0, 1);
+	gtk_widget_set_margin_start (label, MARGIN_BOX);
     tmp_str = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>", title);
     gtk_label_set_markup (GTK_LABEL (label), tmp_str);
     g_free(tmp_str);
@@ -609,10 +609,10 @@ gboolean utils_set_tree_store_background_color (GtkWidget *tree_view,
  *
  * \return      widget initialisé
  * */
-GtkWidget *utils_get_image_with_etat (GtkMessageType msg,
-									  gint initial,
-									  const gchar *tooltip_0,
-									  const gchar *tooltip_1)
+GtkWidget *utils_get_image_with_state (GtkMessageType msg,
+									   gint initial,
+									   const gchar *tooltip_0,
+									   const gchar *tooltip_1)
 {
     GtkWidget *hbox;
     GtkWidget *icon_0;
@@ -662,8 +662,8 @@ GtkWidget *utils_get_image_with_etat (GtkMessageType msg,
  *
  * \return      TRUE if OK FALSE si rien à faire
  * */
-gboolean utils_set_image_with_etat (GtkWidget *widget,
-									gint etat)
+gboolean utils_set_image_with_state (GtkWidget *widget,
+									 gint state)
 {
     GtkWidget *icon_0;
     GtkWidget *icon_1;
@@ -673,16 +673,16 @@ gboolean utils_set_image_with_etat (GtkWidget *widget,
     hbox = g_object_get_data (G_OBJECT (widget), "icon");
 
     initial = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (hbox), "initial"));
-    if (initial == etat)
+    if (initial == state)
         return FALSE;
 
     /* on met la nouvelle valeur pour initial */
-    g_object_set_data (G_OBJECT (hbox), "initial", GINT_TO_POINTER (etat));
+    g_object_set_data (G_OBJECT (hbox), "initial", GINT_TO_POINTER (state));
 
     icon_0 = g_object_get_data (G_OBJECT (hbox), "icon_0");
     icon_1 = g_object_get_data (G_OBJECT (hbox), "icon_1");
 
-    if (etat)
+    if (state)
     {
         gtk_widget_hide (icon_0);
         gtk_widget_show (icon_1);
@@ -1020,6 +1020,8 @@ GtkWidget *utils_widget_csv_separators_new (GtkSizeGroup *size_group,
 					  G_CALLBACK (utils_widget_csv_separators_combo_changed),
 					  entry);
 
+	gtk_combo_box_set_active(GTK_COMBO_BOX (combobox), 0);
+
 	gtk_widget_show_all (hbox);
 
 	return hbox;
