@@ -8,13 +8,11 @@
 
 
 /* START_DECLARATION */
-gchar *			utils_gtkbuilder_get_full_path				(const gchar *name);
 GtkWidget *		utils_gtkbuilder_get_widget_by_name			(GtkBuilder *builder,
                         									 const gchar *gtk_builder_name,
                         									 const gchar *optional_name);
 gint			utils_gtkbuilder_merge_ui_data_in_builder	(GtkBuilder *builder,
 															 const gchar *ui_name);
-GtkBuilder *	utils_gtk_builder_new_from_file				(const gchar *ui_name);
 /* END_DECLARATION */
 
 #endif /* _H_UTILS_GTKBUILDER */
