@@ -4,7 +4,7 @@
 /*          2003-2004 Alain Portal (aportal@univ-montp2.fr)                   */
 /*          2003-2004 Francois Terrot (francois.terrot@grisbi.org)            */
 /*          2008-2017 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -34,7 +34,7 @@
 #include "utils_prefs.h"
 #include "dialog.h"
 #include "grisbi_app.h"
-#include "grisbi_settings.h"
+#include "grisbi_prefs.h"
 #include "gsb_file.h"
 #include "gsb_dirs.h"
 #include "parametres.h"
@@ -44,10 +44,6 @@
 #include "erreur.h"
 /*END_INCLUDE*/
 
-#ifdef GTKOSXAPPLICATION
-#include "grisbi_osx.h"
-#endif  /* GTKOSXAPPLICATION */
-
 /*START_STATIC*/
 /*END_STATIC*/
 
@@ -129,7 +125,6 @@ static void utils_prefs_fonts_update_labels (GtkWidget *button,
     GtkWidget *font_size_label;
 	gchar *font_name;
     gchar *font_size;
-	gchar *label_str;
 
     font_name_label = g_object_get_data (G_OBJECT (button), "name_label");
     font_size_label = g_object_get_data (G_OBJECT (button), "size_label");
@@ -173,23 +168,20 @@ static void utils_prefs_fonts_update_labels (GtkWidget *button,
     }
     else
     {
+		GrisbiAppConf *a_conf;
+
 		font_name = my_strdup ("Monospace");
 		font_size = g_strdup ("10");
-		conf.custom_fonte_listes = FALSE;
+		a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+		a_conf->custom_fonte_listes = FALSE;
     }
 
-	label_str = make_blue (font_name);
-    gtk_label_set_text (GTK_LABEL(font_name_label), label_str);
-	gtk_label_set_use_markup (GTK_LABEL(font_name_label), TRUE);
-	g_free (label_str);
+    gtk_label_set_text (GTK_LABEL(font_name_label), font_name);
 	g_free (font_name);
 
 	if (font_size && strlen (font_size))
 	{
-		label_str = make_blue (font_size);
-		gtk_label_set_text (GTK_LABEL(font_size_label), label_str);
-		gtk_label_set_use_markup (GTK_LABEL(font_size_label), TRUE);
-		g_free (label_str);
+		gtk_label_set_text (GTK_LABEL(font_size_label), font_size);
 		g_free (font_size);
 	}
 }
@@ -245,29 +237,6 @@ static gboolean utils_prefs_fonts_button_choose_font_clicked (GtkWidget *button,
 	return FALSE;
 }
 
-/**
- * set the size of scrolled_window in prefs tab
- *
- * \param table the table which receive the 'size-allocate' signal
- * \param allocation
- *
- * \return FALSE
- * */
-static gboolean utils_prefs_scrolled_window_allocate_size (GtkWidget *widget,
-                                                    GtkAllocation *allocation,
-                                                    gpointer height_ptr)
-{
-	gint height = SW_MIN_HEIGHT;
-
-    /* set the height value */
-    if (height_ptr)
-		height = GPOINTER_TO_INT (height_ptr);
-
-    gtk_widget_set_size_request (widget, SW_MAX_CONTENT_WIDTH, height);
-
-    return FALSE;
-}
-
 /******************************************************************************/
 /* Public functions                                                           */
 /******************************************************************************/
@@ -373,19 +342,22 @@ void utils_prefs_left_panel_add_line (GtkTreeStore *tree_model,
     else
     {
         /* append page onglet*/
+		gchar *tmp_title;
 
+		tmp_title = utils_str_break_form_name_field (title, TRUNC_FORM_FIELD);
 		if (child)
 		{
-            gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, gtk_label_new (title));
+            gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, gtk_label_new (tmp_title));
 		}
 
         gtk_tree_store_append (GTK_TREE_STORE (tree_model), &iter2, page_parent_iter);
         gtk_tree_store_set (GTK_TREE_STORE (tree_model),
 							&iter2,
-							LEFT_PANEL_TREE_TEXT_COLUMN, title,
+							LEFT_PANEL_TREE_TEXT_COLUMN, tmp_title,
 							LEFT_PANEL_TREE_PAGE_COLUMN, page,
 							LEFT_PANEL_TREE_BOLD_COLUMN, 400,
 							-1);
+		g_free (tmp_title);
     }
 }
 
@@ -528,6 +500,7 @@ GtkWidget *utils_prefs_paddinggrid_new_with_title (GtkWidget *parent,
     /* Creating label */
     label = gtk_label_new (NULL);
     utils_labels_set_alignment (GTK_LABEL (label), 0, 1);
+	gtk_widget_set_margin_start (label, MARGIN_BOX);
     gtk_widget_show (label);
 
     tmp_str = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>", title);
@@ -602,23 +575,16 @@ void utils_prefs_page_dir_chosen (GtkWidget *button,
 
 	if (strcmp (dirname, "backup_path") == 0)
 	{
-		GSettings *settings;
-
-        settings = grisbi_settings_get_settings (SETTINGS_FILES_BACKUP);
-        g_settings_set_string (G_SETTINGS (settings), "backup-path", tmp_dir);
-
         gsb_file_set_backup_path (tmp_dir);
 	}
 	else if (strcmp (dirname, "import_directory") == 0)
 	{
-		GSettings *settings;
-
-        settings = grisbi_settings_get_settings (SETTINGS_FILES_FILE);
-        g_settings_set_string (G_SETTINGS (settings), "import-directory", tmp_dir);
-		if (conf.import_directory)
-			g_free (conf.import_directory);
-		conf.import_directory = my_strdup (tmp_dir);
+		GrisbiAppConf *a_conf;
 
+		a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+		if (a_conf->import_directory)
+			g_free (a_conf->import_directory);
+		a_conf->import_directory = my_strdup (tmp_dir);
 	}
 
     g_signal_handlers_unblock_by_func (button,
@@ -626,71 +592,11 @@ void utils_prefs_page_dir_chosen (GtkWidget *button,
 									   dirname);
 
 	utils_prefs_gsb_file_set_modified ();
-    /* memory free */
+
+	/* memory free */
     g_free (tmp_dir);
 }
 
-/**
- * Set a boolean integer to the value of a checkbutton.  Normally called
- * via a GTK "toggled" signal handler.
- *
- * \param eventbox 			a pointer to a eventbox widget.
- * \param event
- * \param checkbutton		check button
- *
- * \return FALSE
-**/
-gboolean utils_prefs_page_eventbox_clicked (GObject *eventbox,
-											GdkEvent *event,
-											GtkToggleButton *checkbutton)
-{
-    gboolean state;
-
-    state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), !state);
-
-    return FALSE;
-}
-
-/**
- *
- *
- * \param
- *
- * \return
- * */
-GtkWidget *utils_prefs_scrolled_window_new (GtkSizeGroup *size_group,
-                                            GtkShadowType type,
-                                            gint coeff_util,
-                                            gint height)
-{
-    GtkWidget *sw = NULL;
-
-	sw = gtk_scrolled_window_new (NULL, NULL);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), type);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-                                    GTK_POLICY_AUTOMATIC,
-                                    GTK_POLICY_AUTOMATIC);
-
-    /* set height */
-    if (!height)
-		height = SW_MIN_HEIGHT;
-
-	gtk_widget_set_size_request (sw, SW_MAX_CONTENT_WIDTH, height);
-
-    /* set signals */
-    g_signal_connect (G_OBJECT (sw),
-                      "size-allocate",
-                      G_CALLBACK (utils_prefs_scrolled_window_allocate_size),
-                      GINT_TO_POINTER (height));
-
-    /* set size_group */
-    if (size_group)
-        g_object_set_data (G_OBJECT (sw), "size_group", size_group);
-
-    return sw;
-}
-
 /**
  *
  *
@@ -764,10 +670,11 @@ GtkWidget *utils_prefs_fonts_create_button (gchar **fontname,
     gtk_container_add (GTK_CONTAINER(font_button), hbox_font);
 
     font_name_label = gtk_label_new (NULL);
-	gtk_widget_set_name (font_name_label, "font_label");
+	gtk_widget_set_name (font_name_label, "label_gsetting_option");
     gtk_box_pack_start (GTK_BOX (hbox_font), font_name_label, TRUE, TRUE, 5);
 
     font_size_label = gtk_label_new (NULL);
+	gtk_widget_set_name (font_size_label, "label_gsetting_option");
     gtk_box_pack_start (GTK_BOX (hbox_font), font_size_label, FALSE, FALSE, 5);
     g_object_set_data (G_OBJECT (font_button), "hook", hook);
     g_object_set_data (G_OBJECT (font_button), "data", data);
@@ -808,6 +715,85 @@ GtkWidget *utils_prefs_create_combo_list_indisponible (void)
     return combobox;
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void utils_prefs_close_prefs_from_theme (void)
+{
+	GtkWidget *prefs;
+
+	prefs = grisbi_win_get_prefs_dialog (NULL);
+	if (GRISBI_IS_PREFS (prefs))
+	{
+		gtk_dialog_response (GTK_DIALOG (prefs), GTK_RESPONSE_CANCEL);
+	}
+}
+
+/**
+ * Warns that there is no coming back if password is forgotten when
+ * encryption is activated.
+ *
+ * \param checkbox  Checkbox that triggered event.
+ * \param data      Unused.
+ *
+ * \return          FALSE
+ **/
+gboolean utils_prefs_encryption_toggled (GtkWidget *checkbox,
+										 gpointer data)
+{
+#ifdef HAVE_SSL
+	GrisbiWinRun *w_run;
+
+	w_run = grisbi_win_get_w_run ();
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox)))
+    {
+        dialogue_message ("encryption-is-irreversible");
+        w_run->new_crypted_file = TRUE;
+    }
+	else
+		w_run->new_crypted_file = FALSE;
+#else
+	gchar *text = _("This build of Grisbi does not support encryption.\n"
+					"Please recompile Grisbi with OpenSSL encryption enabled.");
+	gchar *hint;
+
+	hint = g_strdup_printf (_("Could not encrypt file"));
+	dialogue_error_hint (text, hint);
+	g_signal_handlers_block_by_func (G_OBJECT (checkbox),
+									 G_CALLBACK (utils_prefs_encryption_toggled),
+									 data);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), FALSE);
+
+	g_free (hint);
+	g_signal_handlers_unblock_by_func (G_OBJECT (checkbox),
+									   G_CALLBACK (utils_prefs_encryption_toggled),
+									   data);
+#endif
+    return FALSE;
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void utils_prefs_page_notebook_switch_page (GtkNotebook *notebook,
+											GtkWidget *page,
+											guint page_num,
+											guint *value)
+{
+	if (value)
+    {
+		*value = page_num;
+	}
+}
+
 /**
  *
  *
