@@ -14,9 +14,9 @@
 gchar *		gsb_string_extract_int 									(const gchar *chaine);
 GSList *	gsb_string_get_categ_budget_struct_list_from_string 	(const gchar *string);
 GSList *	gsb_string_get_int_list_from_string 					(const gchar *string,
-						                                             gchar *delimiter);
+						                                             const gchar *delimiter);
 GSList *	gsb_string_get_string_list_from_string 					(const gchar *string,
-						                                             gchar *delimiter);
+						                                             const gchar *delimiter);
 gboolean 	gsb_string_is_trouve 									(const gchar *payee_name,
 									                                 const gchar *needle,
 																	 gint ignore_case,
@@ -24,13 +24,12 @@ gboolean 	gsb_string_is_trouve 									(const gchar *payee_name,
 gchar * 	gsb_string_remplace_joker 								(const gchar *chaine,
 								                                     gchar *new_str);
 gchar *		gsb_string_remplace_string 								(const gchar *str,
-																	 gchar *old_str,
-																	 gchar *new_str);
+																	 const gchar *old_str,
+																	 const gchar *new_str);
 gchar * 	gsb_string_truncate 									(gchar * string);
 gchar *		gsb_string_uniform_new_line 							(const gchar *chaine,
 																	 gssize nbre_char);
-gchar * 	latin2utf8 												(const gchar * inchar);
-gchar *		limit_string 											(gchar *string,
+gchar *		limit_string 											(const gchar *string,
 												                     gint length);
 gint 		my_strcasecmp 										    (const gchar *string_1,
 																	 const gchar *string_2);
@@ -40,12 +39,14 @@ gchar *		my_strdelimit 											(const gchar *string,
 																	 const gchar *delimiters,
 																	 const gchar *new_delimiters);
 gchar *		my_strdup 												(const gchar *string);
-gint 		my_strncasecmp 											(gchar *string_1,
-																	 gchar *string_2,
+gint 		my_strncasecmp 											(const gchar *string_1,
+																	 const gchar *string_2,
 												                     gint longueur);
 gint 		utils_str_atoi 											(const gchar *chaine);
 gchar *		utils_str_break_filename 								(const gchar *string,
 									                                 gint trunc);
+gchar *		utils_str_break_form_name_field							(const gchar *text,
+																	 gint trunc);
 gint 		utils_str_get_nbre_motifs 								(const gchar *chaine,
 																	 const gchar *motif);
 gchar *		utils_str_itoa 											(gint integer);
